function XPCS_Analyze(varargin)
% XPCS_Analyze: Starts the XPCS analysis
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Starting XPCS Analysis'; theString];
set(hMsgBox, 'String', theString);

hFigMain = findall(0,'Tag','main_Fig');
hFileList = findall(0,'Tag','main_fileList');
info = getappdata(hFigMain, 'Info');

hCheckFirst = findall(0,'Tag','analysis_checkFirst');
hCheckPrev = findall(0,'Tag','analysis_checkPrev');
hCheckG2 = findall(0,'Tag','analysis_checkG2');
hCheckDiff = findall(0,'Tag','analysis_checkDiff');

doFirst = get(hCheckFirst, 'Value');
info.Analysis.first = doFirst;
doPrev = get(hCheckPrev, 'Value');
info.Analysis.first = doPrev;
doG2 = get(hCheckG2, 'Value');
info.Analysis.first = doG2;
doDiff = get(hCheckDiff, 'Value');
info.Analysis.first = doDiff;

totAna = doFirst + doPrev + doG2 + doDiff;

fileNames = char(get(hFileList, 'String'));

regions = info.Analysis.regions;
sets = info.Analysis.sets;
avgFiles = info.Analysis.average;
numFiles = size(fileNames,1);
perSet = numFiles/sets;
totalSteps = regions*numFiles;

BGfunc = info.Analysis.BGfunc;
strLen = length(BGfunc);
%work from inside out
Bra = strfind(BGfunc, '(');
numBra = length(Bra);
A = {};
for k = numBra:-1:1
    Bra = strfind(BGfunc, '(');
    Ket = strfind(BGfunc, ')');
    tmpStr = BGfunc(Bra(k)+1:min(Ket(Ket>Bra(k)))-1);
    
    %Get variables assumed to be of form field-scale*field
    Sca = strfind(tmpStr, 'S');
    
    scale = info.Analysis.BGscale{ ...
                int8(str2double(tmpStr(Sca(1)+1))),1};
    switch tmpStr(Sca(1)-3)
      case 'F'
        field1 = info.Analysis.BGfield{ ...
          int8(str2double(tmpStr(Sca(1)-2))),1};
      case 'A'
        field1 = A{ ...
          int8(str2double(tmpStr(Sca(1)-2))),1};
    end
    if(size(field1) ~= size(info.Mask.theData))
        field1 = field1(1,1)*ones(size(info.Mask.theData));
    end
    switch tmpStr(Sca(1)+3)
      case 'F'
        field2 = info.Analysis.BGfield{ ...
          int8(str2double(tmpStr(Sca(1)+4))),1};
      case 'A'
        field2 = A{ ...
          int8(str2double(tmpStr(Sca(1)+4))),1};
    end
    if(size(field2) ~= size(info.Mask.theData))
        field2 = field2(1,1)*ones(size(info.Mask.theData));
    end
    
    countA = length(A)+1;
    [scale, A{countA,1}] = XPCS_imageSub(field1, field2, scale);
	
    BGfunc = [BGfunc(1:Bra(k)-1), 'A', num2str(countA),...
        BGfunc(min(Ket(Ket>Bra(k)))+1:strLen)];
end

%open first image to test mask size and CCD Setup
I_1 = double(hdfread(char(info.Main.files(2)),'data'));

%Check mask size
info.Mask.theData = I_1;
setappdata(hFigMain, 'Info', info);
XPCS_maskSize;

%get new values and Q scaling
info = getappdata(hFigMain, 'Info');
Q = info.Setup.CCDscale;

%check that setup has been initialized
if(size(Q(:,:,1)) ~= size(info.Mask.theData))
XPCS_setupCCDscale;
info = getappdata(hFigMain, 'Info');
Q = info.Setup.CCDscale;
end

%Calculate magnitude of Q and trim using ROI mask
magQ = sqrt(Q(:,:,1).*Q(:,:,1) + Q(:,:,2).*Q(:,:,2) + Q(:,:,3).*Q(:,:,3));
if(mean(mean(info.Mask.theMask)) == 0)
%no ROI -> quite
return;
elseif(mean(mean(info.Mask.theMask)) ~= 1)
%apply filter
magQ = roifilt2(0,magQ+1,1-info.Mask.theMask)-1;
minQ = min(min(magQ(magQ~=-1)));
else
%use entire image
minQ = min(min(magQ));
end
maxQ = max(max(magQ));
stepQ = (maxQ - minQ)/regions;

XPCS_Waitbar;
hWaitbar = findall(0,'Tag','main_waitbar');
figure(hFigMain);
for s = 1:sets
  %open inital file(s)
  I_1 = 0;
  for k = 1:avgFiles
    I_1 = I_1 + double(hdfread(char(info.Main.files((s-1)*perSet+k+1)),'data'));
  end
  I_1 = I_1/avgFiles;
  
  %calculate background correction
  field1 = I_1;
  Sca = strfind(BGfunc, 'S');
  
  BGfield = 0;
  for j = 1:length(Sca)
    scale = info.Analysis.BGscale{ ...
      int8(str2double(BGfunc(Sca(j)+1))),1};
    switch BGfunc(Sca(j)+3)
      case 'F'
        field2 = info.Analysis.BGfield{ ...
          int8(str2double(BGfunc(Sca(j)+4))),1};
      case 'A'
        field2 = A{ ...
          int8(str2double(BGfunc(Sca(j)+4))),1};
    end
    if(size(field2) ~= size(info.Mask.theData))
      field2 = field2(1,1)*ones(size(info.Mask.theData));
    end
    [scale, field1] = XPCS_imageSub(field1, field2, scale);
    BGfield = BGfield + scale*field2;
  end

  g2First = zeros(uint16(perSet/avgFiles), regions);
  diffFirst = zeros(uint16(perSet/avgFiles), regions);
  g2Prev = zeros(uint16(perSet/avgFiles), regions);
  diffPrev = zeros(uint16(perSet/avgFiles), regions);

  I_1 = I_1 - BGfield;
  if(doPrev)
    I_m = I_1;
  end
  
  for j = 1:uint16(perSet/avgFiles)
    I_n = 0;
    for k = 1:avgFiles
        I_n = I_n + double(hdfread(char(info.Main.files((s-1)*perSet+(j-1)*avgFiles+k+1)),'data'));
    end
    I_n = I_n/avgFiles;
    I_n = I_n - BGfield;

    theCount = 0;
    if(doFirst)
      if(doG2)
        I1xIn = I_1.*I_n;
        theCount = theCount + 1;
        for r = 1:regions
          num = mean(I1xIn(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)));
          den1 = mean(I_1(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)));
          den2 = mean(I_n(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)));
          g2First(j,r)= num/(den1*den2) - 1;
          waitbar(((s-1)+((double(j)-1)+((theCount-1)+r/regions) ...
              /totAna)*(avgFiles/perSet))/sets, hWaitbar);
        end
      end
      if(doDiff)
        theCount = theCount + 1;
        for r = 1:regions
          diffFirst(j,r) = 2*sum(sum( ...
            min(I_1(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)), ...
                I_n(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ))))) ...
           /sum(sum(I_1(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)) ...
                   +I_n(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ))));
          waitbar(((s-1)+((double(j)-1)+((theCount-1)+r/regions) ...
              /totAna)*(avgFiles/perSet))/sets, hWaitbar);
        end
      end
    end
    if(doPrev)
      if(doG2)
        theCount = theCount + 1;
        ImxIn = I_m.*I_n;
        for r = 1:regions
          num = mean(ImxIn(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)));
          den1 = mean(I_m(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)));
          den2 = mean(I_n(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)));
          g2Prev(j,r)= num/(den1*den2) - 1;
          waitbar(((s-1)+((double(j)-1)+((theCount-1)+r/regions) ...
              /totAna)*(avgFiles/perSet))/sets, hWaitbar);
        end
      end
      if(doDiff)
        theCount = theCount + 1;
        for r = 1:regions
          diffPrev(j,r) = 2*sum(sum( ...
            min(I_m(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)), ...
                I_n(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ))))) ...
           /sum(sum(I_m(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ)) ...
                   +I_n(magQ>=(minQ + (r-1)*stepQ) & magQ<=(minQ + r*stepQ))));
          waitbar(((s-1)+((double(j)-1)+((theCount-1)+r/regions) ...
              /totAna)*(avgFiles/perSet))/sets, hWaitbar);
        end
      end
      I_m = I_n;
    end
  end
  %save analysis "XPCS_[start file]-[end file]_date_time.txt"
  theCount = 0;
  fileSave = zeros(perSet/avgFiles, totAna);
  if(doFirst)
    if(doG2)
      theCount = theCount + 1;
      fileSave(:,theCount) = g2First;
    end
    if(doDiff)
      theCount = theCount + 1;
      fileSave(:,theCount) = diffFirst;
    end
  end
  if(doPrev)
    if(doG2)
      theCount = theCount + 1;
      fileSave(:,theCount) = g2Prev;
    end
    if(doDiff)
      theCount = theCount + 1;
      fileSave(:,theCount) = diffPrev;
    end
  end
  startFile = fileNames((s-1)*perSet+1,:);
  endFile = fileNames((s)*perSet,:);
  startP = strfind(startFile, '.')-1;
  endP = strfind(endFile, '.')-1;
  theNow = datevec(now);
  nowStr = sprintf('%04d%02d%02d%02d%02d%02d', theNow(1), theNow(2), ...
      theNow(3), theNow(4), theNow(5), floor(theNow(6)));
  fname = ['XPCS_', startFile(1:startP(1)), '-', ...
      endFile(1:endP(1)), '_', nowStr, '.txt'];
  save(fname, 'fileSave', '-ASCII');
end

waitbar(1, hWaitbar);
delete(hWaitbar)
%-----
% EOF
%-----
