function XPCS_Analyze2(varargin)
% XPCS_Analyze: Starts the XPCS analysis
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Starting XPCS Analysis'; theString];
set(hMsgBox, 'String', theString);

hFigMain = findall(0,'Tag','main_Fig');
hFileList = findall(0,'Tag','main_fileList');
info = getappdata(hFigMain, 'Info');
regions = 1;
%regions = info.Analysis.regions;
numFiles = size(info.Main.files,1);
totalSteps = regions*numFiles;
num2avg = 1;
theSet = 20;

if(isempty(info.Main.files(2)))
    pname = pwd;
else
    %use first file as current directory
    aname = char(info.Main.files(2));
    fname = get(hFileList, 'String');
    k = strfind(aname, fname{1,1});
    pname = aname(1 : k(1)-2);
end

%Open multiple Files
[fname,pname,dataType] = uigetfile({'*.hdf','*.hdf';'*.FITS','*.FITS'}, ...
    'Select DarkFields', pname, 'MultiSelect', 'on');
if(isa(fname,'char'))
  darkImg = double(hdfread(sprintf('%s%s', pname, char(fname)),'data'));
else
  tmp = 0;
  for k = 1:size(fname,2)
    tmp = tmp + double(hdfread(sprintf('%s%s', pname, char(fname(k))),'data'));
  end
  darkImg = tmp/size(fname,2);
end
%average dark fiels
%num = size(darkFiles, 2);
%tmp = 0;
%for k = 1:num
%    tmp =  tmp + double(hdfread(darkFiles(1,:),'data'));
%end
%darkImg = tmp/num;

%Open multiple Files
[fname,pname,dataType] = uigetfile({'*.hdf','*.hdf';'*.FITS','*.FITS'}, ...
    'Select WhiteFields', pname, 'MultiSelect', 'on');
if(isa(fname,'char'))
  whiteFiles = sprintf('%s%s', pname, char(fname));
else
  for k = 1:size(fname,2)
    whiteFiles(k,:) = sprintf('%s%s', pname, char(fname(k)));
  end
end
%average white fiels
num = size(whiteFiles, 2);
tmp = 0;
for k = 1:num
    tmp =  tmp + double(hdfread(whiteFiles(1,:),'data'));
end
whiteImg = tmp/num;

%dataFiles = zeros(1,theSet);
for k = 2:theSet+1
    dataFiles(k-1,:) = char(info.Main.files(k));
end

[darkFac sWhtImg whiteFac] = ...
    XPCS_scaleFactor(dataFiles, darkImg, whiteImg);

I_1 = 0;
for k = 2:1+num2avg
    I_1 = I_1 + double(hdfread(char(info.Main.files(k)),'data'));
end
I_1 = I_1/num2avg;
I_1 = I_1 -darkFac*darkImg - whiteFac*sWhtImg;

info.Mask.theData = I_1;
setappdata(hFigMain, 'Info', info);
XPCS_maskSize;

info = getappdata(hFigMain, 'Info');
Q = info.Setup.CCDscale;

if(size(Q(:,:,1)) ~= size(info.Mask.theData))
    XPCS_setupCCDscale;
    info = getappdata(hFigMain, 'Info');
    Q = info.Setup.CCDscale;
end

magQ = sqrt(Q(:,:,1).*Q(:,:,1) + Q(:,:,2).*Q(:,:,2) + Q(:,:,3).*Q(:,:,3));
if(mean(mean(info.Mask.theMask)) == 0)
    %no ROI -> quite
    return;
elseif(mean(mean(info.Mask.theMask)) ~= 1)
    %apply filter
    magQ = roifilt2(0,magQ+1,1-info.Mask.theMask)-1;
    minQ = min(min(magQ(magQ~=-1)));
else
    %use entire image
    minQ = min(min(magQ));
end
maxQ = max(max(magQ));
stepQ = (maxQ - minQ)/regions;

%I_1 = sparse(double(roifilt2(0,I_1,1-info.Mask.theMask))); %fill R-not-OI with black(zeros)
%sparse is actually slower, unless its less then ~10%
%for each frame calculate g2(N)-1:

XPCS_Waitbar;
hWaitbar = findall(0,'Tag','main_waitbar');



g2 = zeros((size(info.Main.files,1)-1)/num2avg, regions);
h2 = zeros((size(info.Main.files,1)-1)/num2avg, regions);
waitbar(regions/totalSteps, hWaitbar);
for k = 1:uint16((numFiles-1)/num2avg)
    I_n = 0;
    for j = 1:num2avg
        I_n = I_n + double(hdfread(char(info.Main.files((k-1)*num2avg+j+1)),'data'));
    end
    I_n = I_n/num2avg;
    I_n = I_n -darkFac*darkImg - whiteFac*sWhtImg;
    
    %I_n = double(hdfread(char(info.Main.files(k)),'data'));
    %apply mask:
    %I_n = sparse(double(roifilt2(0,I_n,1-info.Mask.theMask)));

    %multiply element by element
    %I1xIn = I_1.*I_n;
    I1xIn = (I_1-min(min(I_1))).*(I_n-min(min(I_n)));

    for j = 1:regions
        num = mean(I1xIn(magQ>=(minQ + (j-1)*stepQ) & magQ<=(minQ + j*stepQ)));
        den1 = mean(I_1(magQ>=(minQ + (j-1)*stepQ) & magQ<=(minQ + j*stepQ))-min(min(I_1)));
        den2 = mean(I_n(magQ>=(minQ + (j-1)*stepQ) & magQ<=(minQ + j*stepQ))-min(min(I_n)));
        g2(k,j)= num/(den1*den2) - 1;
        h2(k,j)= 2*sum(sum(min(I_1-min(min(I_1)),I_n-min(min(I_n)))))/sum(sum(I_1+I_n-min(min(I_1))-min(min(I_n))));
        waitbar(double((k*num2avg)*regions+j)/totalSteps, hWaitbar);
    end
    %calc ave of all q > 0 (outside mask);
    %aveI1xIn = mean(mean( I1xIn(I1xIn>0) ));
    %aveI_1 = mean(mean( I_1(I_1>0) ));
    %aveI_n = mean(mean( I_n(I_n>0) ));
    


    %correlation step function: g2(N) - 1 = <I(q,1)*I(q,N)>/<I(q,N)>^2 - 1
    %g2(k-2)= aveI1xIn/aveI_1/aveI_n - 1;

    %active readout:
    %disp(['g2(' int2str(k-2) ') = ' num2str(g2(k-2))]);


    %active view:
    %%{

    %input vector for plot function.
    %n = 1:numel(g2);
    
    %window
    %figure(2)
    
    %fixed frame:
    %subplot(2,2,3)
    %imagesc(I_1)
    %colorbar('location','EastOutside')
    %caxis([0, 1.0E4])
    
    %Nth frame:
    %subplot(2,2,4)
    %imagesc(I_n)
    %colorbar('location','EastOutside')
    %caxis([0, 1.0E4])

    %Correlation Function:
    %subplot(2,2,1:2)
    %plot(n,g2)

    %}
end
delete(hWaitbar)
figure(5); plot(g2)
figure(6); plot(h2)

%-----
% EOF
%-----