function varargout = XPCS_AnalyzeGUI(varargin)
% XPCS_AnalyzeGUI: Open GUI to define analysis of data
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Opening anlysis setup interface'; theString];
set(hMsgBox, 'String', theString);

hFigAnalysis = findall(0,'Tag','analysis_Fig');
if isempty(hFigAnalysis)
    initFigure;
else
    figure(hFigAnalysis);
end

%================================================================
% --- initialize main figure layout
%================================================================
function initFigure
hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain,'Info');
% --------------------------------
% --- main figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [750 540];
figurePos  = [150 130 figureSize];
hFigAnalysis = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Analysis Setup',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','analysis_Fig',...
    'CloseRequestFcn',@analysis_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigAnalysis,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','analysis_Axes');
hGroupPatch = hggroup('Parent',hAxes);
hPatchMain = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --- layout of controls
hTextType = uicontrol(hFigAnalysis,...
    'Style','text',...
    'Units','characters',...
    'String','Analysis type (check all that apply):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[10 38 50 1.6],...
    'Tag','analysis_textType');
hCheckFirst = uicontrol(hFigAnalysis,...
    'Style','checkbox',...
    'Units','characters',...
    'String','First frame',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'Value', info.Analysis.first,...
    'position',[10 36 50 1.6],...
    'Tag','analysis_checkFirst',...
    'TooltipString','Autocorralate each set of images to their respective first frame');
hCheckPrev = uicontrol(hFigAnalysis,...
    'Style','checkbox',...
    'Units','characters',...
    'String','Previous frame',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'Value', info.Analysis.previous,...
    'position',[10 34 50 1.6],...
    'Tag','analysis_checkPrev',...
    'TooltipString','Autocorralate each set of images to their respective previous frame');
hCheckG2 = uicontrol(hFigAnalysis,...
    'Style','checkbox',...
    'Units','characters',...
    'String','Calculate g2',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'Value', info.Analysis.g2,...
    'position',[10 32 50 1.6],...
    'Tag','analysis_checkG2',...
    'TooltipString','Calculated g2 function');
hCheckDiff = uicontrol(hFigAnalysis,...
    'Style','checkbox',...
    'Units','characters',...
    'String','Calculate Norm. Diff.',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'Value', info.Analysis.normDiff,...
    'position',[10 30 50 1.6],...
    'Tag','analysis_checkDiff',...
    'TooltipString','Calculate the normalized difference function');
hTextType = uicontrol(hFigAnalysis,...
    'Style','text',...
    'Units','characters',...
    'String','Division of files:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[90 38 45 1.6],...
    'Tag','analysis_textType');
hTextSets = uicontrol(hFigAnalysis,...
    'Style','text',...
    'Units','characters',...
    'String','Data Sets:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[90 36 25 1.6],...
    'Tag','analysis_textSets');
hEditSets = uicontrol(hFigAnalysis,...
    'Style','edit',...
    'Units','characters',...
    'String', num2str(info.Analysis.sets),...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[120 36 15 1.6],...
    'Tag','analysis_editSets',...
    'TooltipString','Enter the number of independent data sets contained with in the files',...
    'callback',@XPCS_fileDivision);
hTextAvg = uicontrol(hFigAnalysis,...
    'Style','text',...
    'Units','characters',...
    'String','Average:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[90 34 25 1.6],...
    'Tag','analysis_textAvg');
hEditAvg = uicontrol(hFigAnalysis,...
    'Style','edit',...
    'Units','characters',...
    'String', num2str(info.Analysis.average),...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[120 34 15 1.6],...
    'Tag','analysis_editAvg',...
    'TooltipString','Enter how many files to group and average before analysis',...
    'callback',@XPCS_fileDivision);
hTextRegions = uicontrol(hFigAnalysis,...
    'Style','text',...
    'Units','characters',...
    'String','Const-Q Regions:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[90 32 25 1.6],...
    'Tag','analysis_textRegions');
hEditQRegions = uicontrol(hFigAnalysis,...
    'Style','edit',...
    'Units','characters',...
    'String', num2str(info.Analysis.regions),...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[120 32 15 1.6],...
    'Tag','analysis_editQRegions',...
    'TooltipString','Enter the number of constant Q regions the ROI should be split into',...
    'callback',@XPCS_fileDivision);
hTextPre = uicontrol(hFigAnalysis,...
    'Style','text',...
    'Units','characters',...
    'String','Background Subtraction:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[10 26 50 1.6],...
    'Tag','analysis_textPre');
hEditBG = uicontrol(hFigAnalysis,...
    'Style','edit',...
    'Units','characters',...
    'String', info.Analysis.BGfunc,...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[10 24 50 1.6],...
    'Tag','analysis_editBG',...
    'TooltipString','Enter the background subtraction directly or use the buttons to create the background subtraction string',...
    'callback',@XPCS_defineBGVar);
hButtonOK = uicontrol(hFigAnalysis,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Do It!',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','on',...
    'position',[5 5 20 1.6],...
    'Tag','analysis_buttonOK',...
    'TooltipString','Analyzes the current data set with the current settings',...
    'callback',@XPCS_Analyze);

%==========================================================================
% --- close request function of xpcsmask fig 
%==========================================================================
function analysis_CloseRequestFcn(hObject,eventdata)                             %#ok<INUSD>
delete(findall(0,'Tag','analysis_Fig'))                                        ;
%----
% EOF
%----