function varargout = XPCS_MainGUI(varargin)
% XPCS_MainGUI: Open GUI to analyze XPCS data
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.1  Date: 2010/10/28

hFigMain = findall(0,'Tag','main_Fig');
if isempty(hFigMain)
    initFigure;
else
    figure(hFigMain);
end

%================================================================
% --- initialize main figure layout
%================================================================
function initFigure
% --------------------------------
% --- main figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [720 540];
figurePos  = [100 100 figureSize];
hFigMain = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Analysis Program',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','main_Fig',...
    'CloseRequestFcn',@main_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigMain,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','main_Axes');
hPatchMain = patch(...
    'Parent',hAxes,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
hGroupPatch = hggroup('Parent',hAxes);
hPatchButton = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 .2 .2 0],...
    'YData',[0.1 0.1 1 1]);
hPatchFiles = patch(...
    'Parent',hGroupPatch,...
    'XData',[0.2 .5 .5 0.2],...
    'YData',[0.1 0.1 1 1]);
hPatchMessage = patch(...
    'Parent',hGroupPatch,...
    'XData',[0.5 1 1 0.5],...
    'YData',[0.1 0.1 1 1]);
hPatchTimebar = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 0.1 0.1]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --------------------------------
% --- file menu handles
% --------------------------------
hMenuFile = uimenu(hFigMain,...
    'Label','&File',...
    'HandleVisibility','callback',...
    'Tag','main_MenuFile');
hMenuFileOpen = uimenu(hMenuFile,...
    'Label','&Open File(s)...',...
    'HandleVisibility','callback',...
    'Tag','main_MenuFileOpen',...
    'Accelerator','O',...
    'callback',@XPCS_openFiles); % additional m-file
hMenuFolderOpen = uimenu(hMenuFile,...
    'Label','&Open Folder ...',...
    'HandleVisibility','callback',...
    'Tag','main_MenuFolderOpen',...
    'Accelerator','F',...
    'callback',@XPCS_openFolder); %additional m-file
hMenuFileClose = uimenu(hMenuFile,...
    'Label','&Close',...
    'HandleVisibility','callback',...
    'Separator','on',...
    'Tag','xpcsmain_MenuFileClose',...
    'Accelerator','Q',...
    'callback',@main_CloseRequestFcn); %function within this m-file

% --- layout of control panel pushbuttons
text('Parent',hAxes,...
    'Position',[0.1 .96],...
    'FontSize', 12,...
    'FontWeight', 'Bold',...
    'String','Control Panel',...
    'Units','normalized',...
    'HorizontalAlignment','Center',...
    'Color',[0.0 0.0 0]);
hButtonSetup = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Setup',...
    'FontSize', 10,...
    'position',[0.025 0.78 0.15 0.05],...
    'Tag','main_buttonSetup',...
    'TooltipString','Allows you define the Experimental Setup',...
    'Enable','on',...
    'callback',@XPCS_setupGUI);
hButtonMask = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Mask',...
    'FontSize', 10,...
    'position',[0.025 0.68 0.15 0.05],...
    'Tag','main_buttonMask',...
    'TooltipString','Allows you to view and edit the Region of Interest',...
    'Enable','on',...
    'callback',@XPCS_MaskSelectGUI);
hButtonUp = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Up',...
    'FontSize', 10,...
    'position',[0.025 0.58 0.15 0.05],...
    'Tag','main_buttonUp',...
    'TooltipString','Moves selected files up',...
    'Enable','off',...
    'callback',@XPCS_moveup);
hButtonDown = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Down',...
    'FontSize', 10,...
    'position',[0.025 0.52 0.15 0.05],...
    'Tag','main_buttonDown',...
    'TooltipString','Moves selected files down',...
    'Enable','off',...
    'callback',@XPCS_movedn);
hButtonReset = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Reset',...
    'FontSize', 10,...
    'position',[0.025 0.46 0.15 0.05],...
    'Tag','main_buttonReset',...
    'TooltipString','Resets the file order to alphapetical',...
    'Enable','off',...
    'callback',@XPCS_reset);
hButtonRemove = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Remove',...
    'FontSize', 10,...
    'position',[0.025 0.40 0.15 0.05],...
    'Tag','main_buttonRmv',...
    'TooltipString','Removes the selected files',...
    'Enable','off',...
    'callback',@XPCS_remove);
hButtonRun = uicontrol(hFigMain,...
    'Style','pushbutton',...
    'Units','normalized',...
    'String','Analyze',...
    'FontSize', 10,...
    'Enable','off',...
    'position',[0.025 0.20 0.15 0.05],...
    'Tag','main_buttonRun',...
    'TooltipString','Start Analysis',...
    'callback',@XPCS_AnalyzeGUI);

% --- layout of file list display
text('Parent',hAxes,...
    'Position',[.30 .96],...
    'FontSize', 12,...
    'FontWeight', 'Bold',...
    'String','Files to Correlate',...
    'Units','normalized',...
    'HorizontalAlignment','Center',...
    'Color',[0.0 0.0 0]);
hFileList = uicontrol(hFigMain,... %does it need a CreatFcn or Callback?
    'Style','listbox',...
    'Units','characters',...
    ...%'String','Load information file',...
    'position',[30 12.7 40 26],...
    'Max', 2,...
    'Min', 0,...
    'FontSize', 12,...
    'Tag','main_fileList',...
    'TooltipString','Place Files in order of analysis',...
    'BackgroundColor', backColor,...
    'ForegroundColor', [1 1 1]);
hTextCount = uicontrol(hFigMain,...
    'Style','text',...
    'Units','characters',...
    'String','# Files: 0',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[30 10.7 40 1.6],...
    'Tag','main_textCount');
hTextSize = uicontrol(hFigMain,...
    'Style','text',...
    'Units','characters',...
    'String','Size: 0.00 MB',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[30 8.7 40 1.6],...
    'Tag','main_textSize');
hTextLargestFile = uicontrol(hFigMain,...
    'Style','text',...
    'Units','characters',...
    'String','Largest:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[30 6.7 40 1.6],...
    'Tag','main_textLargestFile');
hTextLargestSize = uicontrol(hFigMain,...
    'Style','text',...
    'Units','characters',...
    'String','Size: 0.00 MB',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[30 4.7 40 1.6],...
    'Tag','main_textLargestSize');

% --- layout of message display
text('Parent',hAxes,...
    'Position',[.615 .96],...
    'FontSize', 12,...
    'FontWeight', 'Bold',...
    'String','Message Display',...
    'Units','normalized',...
    'HorizontalAlignment','Center',...
    'Color',[0.0 0.0 0]);
hMsgBox = uicontrol(hFigMain,... 
    'Style','edit',...
    'Units','characters',...
    'Max', 1,...
    'String',{'Welcome to the XPCS Analysis tool'},...
    'Position',[75 6.7 65 32],...
    'Enable', 'inactive',...
    'FontSize', 12,...
    'Tag','main_MsgBox',...
    'BackgroundColor', backColor,...
    'ForegroundColor', [1 1 1],...
    'HorizontalAlignment', 'Left',...
    'Max', 100);

% -----
% set default values
% -----
XPCS_setDefaultInfo

%==========================================================================
% --- close request function of xpcsmain fig 
%==========================================================================
function main_CloseRequestFcn(hObject,eventdata)
delete(findall(0,'Tag','movie_Fig'));
delete(findall(0,'Tag','analysis_Fig'));
delete(findall(0,'Tag','setup_Fig'));
delete(findall(0,'Tag','mask_Fig'));
delete(findall(0,'Tag','main_Fig'));

%----
% EOF
%----