function varargout = XPCS_MaskSelectGUI(varargin)
% XPCS_MaskSelectGUI: Open GUI to define a region to correlate
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 2.0  Date: 2010/10/26

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Opening mask selection interface'; theString];
set(hMsgBox, 'String', theString);

hFigMask = findall(0,'Tag','mask_Fig');
if isempty(hFigMask)
    initFigure;
else
    figure(hFigMask);
end

%================================================================
% --- initialize mask figure layout
%================================================================
function initFigure
hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain,'Info');
% --------------------------------
% --- mask figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [750 540];
figurePos  = [150 130 figureSize];
hFigMask = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Mask Selection',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','mask_Fig',...
    'CloseRequestFcn',@mask_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigMask,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','mask_Axes');
hGroupPatch = hggroup('Parent',hAxes);
hPatchMain = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --------------------------------
% --- file menu handles
% --------------------------------
hMenuFile = uimenu(hFigMask,...
    'Label','&File',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuFile');
hMenuOpen = uimenu(hMenuFile,...
    'Label','&Open ...',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuFileOpen',...
    'Accelerator','O',...
    'callback',@XPCS_maskOpenFile);
hMenuRemove = uimenu(hMenuFile,...
    'Label','&Remove Data',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuFileRemove',...
    'Accelerator','O',...
    'callback',@XPCS_maskRemoveFile);
hMenuClose = uimenu(hMenuFile,...
    'Label','&Close',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuClose',...
    'Accelerator','Q',...
    'callback',@mask_CloseRequestFcn); %function within this m-file

% --------------------------------
% --- mask menu handles
% --------------------------------
hMenuMask = uimenu(hFigMask,...
    'Label','&Mask',...
    'Tag','mask_MenuMask');
hMaskChange = uimenu(hMenuMask,...
    'Label','&Add/Remove',...
    'Tag','mask_MenuChange');
hMaskRect = uimenu(hMaskChange,...
    'Label','&Rectangle',...
    'Tag','mask_MenuRect',...
    'callback', @XPCS_ROIshape);
hMaskEllip = uimenu(hMaskChange,...
    'Label','&Ellipse',...
    'Tag','mask_MenuEllip',...
    'callback', @XPCS_ROIshape);
hMaskPoly = uimenu(hMaskChange,...
    'Label','&Polygon',...
    'Tag','mask_MenuPoly',...
    'callback', @XPCS_ROIshape);
hMaskFree = uimenu(hMaskChange,...
    'Label','&Free Hand',...
    'Tag','mask_MenuFree',...
    'callback', @XPCS_ROIshape);
hMaskAll = uimenu(hMenuMask,...
    'Label','&Select All',...
    'Tag','mask_MenuAll',...
    'callback', @XPCS_ROIentire);
hMaskNone = uimenu(hMenuMask,...
    'Label','&Select None',...
    'Tag','mask_MenuNone',...
    'callback', @XPCS_ROIentire);
hMaskCut = uimenu(hMenuMask,...
    'Label','&Select Cutoff',...
    'Tag','mask_MenuCut',...
    'callback', @XPCS_ROIcutoff);
hMaskExpand = uimenu(hMenuMask,...
    'Label','&Expand Selected',...
    'Tag','mask_MenuExpand',...
    'callback', @XPCS_ROIexpand,...
    'Enable', 'off');
hMaskUndo = uimenu(hMenuMask,...
    'Label','&Undo Last',...
    'Separator','on',...
    'Tag','mask_MenuUndo',...
    'Accelerator','Z',...
    'callback', @XPCS_undoMask);
hMaskHide = uimenu(hMenuMask,...
    'Label','&Hide',...
    'Separator','on',...
    'Tag','mask_MenuHide',...
    'Accelerator','H',...
    'callback', @XPCS_hideMask);
hMaskImport = uimenu(hMenuMask,...
    'Label','&Import ...',...
    'Separator','on',...
    'Tag','mask_MenuImport',...
    'Accelerator','I',...
    'callback', @XPCS_maskImport);
hMaskExport = uimenu(hMenuMask,...
    'Label','&Export ...',...
    'Tag','mask_MenuExport',...
    'Accelerator','E',...
    'callback', @XPCS_maskExport);

% --------------------------------
% --- Tools menu handles
% --------------------------------
hMenuTools = uimenu(hFigMask,...
    'Label','&Tools',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuTools');
hMenuArrow = uimenu(hMenuTools,...
    'Label','&Arrow',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuToolsArrow',...
    'Checked', 'on',...
    'callback',@XPCS_interactive);
hMenuZoom = uimenu(hMenuTools,...
    'Label','&Zoom',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuToolsZoom',...
    'Checked', 'off',...
    'callback',@XPCS_interactive);
hMenuPan = uimenu(hMenuTools,...
    'Label','&Pan',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuToolsPan',...
    'Checked', 'off',...
    'callback',@XPCS_interactive);
hMenuCursor = uimenu(hMenuTools,...
    'Label','&Data Cursor',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuToolsCursor',...
    'Checked', 'off',...
    'callback',@XPCS_interactive);
hMenuReset = uimenu(hMenuTools,...
    'Label','&Reset View',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuToolsReset',...
    'Checked', 'off',...
    'callback',@XPCS_interactive);
hMenuScale = uimenu(hMenuTools,...
    'Label','&Scale',...
    'HandleVisibility','callback',...
    'Separator','on',...
    'Tag','mask_MenuScale');
hMenuLinear = uimenu(hMenuScale,...
    'Label','&Linear',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuScaleLinear',...
    'Checked', 'off',...
    'callback',@XPCS_mapImg);
hMenuSqrt = uimenu(hMenuScale,...
    'Label','&Square Root',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuScaleSqrt',...
    'Checked', 'off',...
    'callback',@XPCS_mapImg);
hMenuLog = uimenu(hMenuScale,...
    'Label','&Logarithmic',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuScaleLog',...
    'Checked', 'off',...
    'callback',@XPCS_mapImg);
hMenuTmap = uimenu(hMenuScale,...
    'Label','&Tone Mapping',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuScaleTmap',...
    'Checked', 'off',...
    'callback',@XPCS_mapImg);
hMenuColor = uimenu(hMenuTools,...
    'Label','&Colormap',...
    'HandleVisibility','callback',...
    'Separator','on',...
    'Tag','mask_MenuColor');
hMenuGray = uimenu(hMenuColor,...
    'Label','&Gray',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuColorGray',...
    'Checked', 'off',...
    'callback',@XPCS_colormap);
hMenuJet = uimenu(hMenuColor,...
    'Label','&Spectrum',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuColorJet',...
    'Checked', 'off',...
    'callback',@XPCS_colormap);
hMenuHSV = uimenu(hMenuColor,...
    'Label','&Rainbow',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuColorHSV',...
    'Checked', 'off',...
    'callback',@XPCS_colormap);
hMenuHot = uimenu(hMenuColor,...
    'Label','&Heat',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuColorHot',...
    'Checked', 'off',...
    'callback',@XPCS_colormap);
hMenuCool = uimenu(hMenuColor,...
    'Label','&Cool',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuColorCool',...
    'Checked', 'off',...
    'callback',@XPCS_colormap);

% --------------------------------
% --- Movie menu handles
% --------------------------------
hMenuMovie = uimenu(hFigMask,...
    'Label','&Movie',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuMovie');
hMenuControls = uimenu(hMenuMovie,...
    'Label','&Open Controls...',...
    'HandleVisibility','callback',...
    'Tag','mask_MenuMovieControls',...
    'callback',@XPCS_MovieGUI);

% --------------------------------
% --- layout of plot
% --------------------------------
text('Parent',hAxes,...
    'Position',[0.07 .96],...
    'FontSize', 12,...
    'FontWeight', 'Bold',...
    'String','Create a mask to correlate a region of interest.',...
    'Units','normalized',...
    'HorizontalAlignment','Left',...
    'Color',[0.0 0.0 0]);
hPlot = axes(...
    'Parent',hFigMask,...
    'Units','pixels',...
    'Position',[50 50 525 450],...
    'Tag','mask_Plot');

% --------------------------------
% --- layout of controls
% --------------------------------
hTextLimit1 = uicontrol(hFigMask,...
    'Style','text',...
    'Units','characters',...
    'String','Lower Limit:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[123 34 20 1.6],...
    'Tag','mask_textLimit1',...
    'Enable','on');
hEditLimit1 = uicontrol(hFigMask,...
    'Style','edit',...
    'Units','characters',...
    'String','',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[123 32.2 20 1.6],...
    'Tag','mask_editLimit1',...
    'TooltipString','Enter a low cutoff for plotting',...
    'Enable','on',...
    'String', info.Mask.lowLmt,...
    'callback',@XPCS_Limit);
hTextLimit2 = uicontrol(hFigMask,...
    'Style','text',...
    'Units','characters',...
    'String','Upper Limit:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[123 30 20 1.6],...
    'Tag','mask_textLimit2',...
    'Enable','on');
hEditLimit2 = uicontrol(hFigMask,...
    'Style','edit',...
    'Units','characters',...
    'String','',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[123 28.2 20 1.6],...
    'Tag','mask_editLimit2',...
    'TooltipString','Enter a upper cutoff for plotting',...
    'Enable','on',...
    'String', info.Mask.highLmt,...
    'callback',@XPCS_Limit);
hTextContrast = uicontrol(hFigMask,...
    'Style','text',...
    'Units','characters',...
    'String','Mask Contrast',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[123 21 24 1.6],...
    'Tag','mask_textContrast',...
    'Enable','on');
hSliderContrast = uicontrol(hFigMask,...
    'Style','slider',...
    'Units','characters',...
    'position',[123 19 24 1.6],...
    'Tag','mask_sliderContrast',...
    'Enable','on',...
    'Max', .9,...
    'Min', .1,...
    'Value', .3,...
    'callback',@XPCS_contrast);
hTextLimit3 = uicontrol(hFigMask,...
    'Style','text',...
    'Units','characters',...
    'String','Cutoff:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[123 14 10 1.6],...
    'Tag','mask_textLimit3',...
    'Enable','on',...
    'Visible','off');
hEditLimit3 = uicontrol(hFigMask,...
    'Style','edit',...
    'Units','characters',...
    'String','',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[123 12 20 1.6],...
    'Tag','mask_editLimit3',...
    'TooltipString','Enter a cutoff for selecting a ROI',...
    'Enable','on',...
    'Visible','off',...
    'Value', 1,...
    'callback',@XPCS_limitCutoff);
hButtonLimit3 = uicontrol(hFigMask,...
    'Style','togglebutton',...
    'Units','characters',...
    'String','Above',...
    'FontSize', 10,...
    'Value', 1,...
    'Enable','on',...
    'Visible','off',...
    'position',[133 14 10 1.6],...
    'Tag','mask_buttonLimit3',...
    'TooltipString','Select ROI Above or Below limit',...
    'callback',@XPCS_limitCutoff);
hButtonToggle = uicontrol(hFigMask,...
    'Style','togglebutton',...
    'Units','characters',...
    'String','Add',...
    'FontSize', 10,...
    'Value', 1,...
    'Enable','on',...
    'Visible','off',...
    'position',[123 10 20 1.6],...
    'Tag','mask_buttonToggle',...
    'TooltipString','Add or Remove the selected ROI to the current Mask',...
    'callback',@XPCS_ROItoggle);
hButtonAccept = uicontrol(hFigMask,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Accept ROI',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','off',...
    'position',[123 8 20 1.6],...
    'Tag','mask_buttonAccept',...
    'TooltipString','Accept the Current Mask',...
    'callback',@XPCS_ROIaccept);
hButtonCancel = uicontrol(hFigMask,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Cancel ROI',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','off',...
    'position',[123 5 20 1.6],...
    'Tag','mask_buttonCancel',...
    'TooltipString','Cancel this ROI',...
    'callback',@XPCS_ROIcancel);

% --------------------------------
% Default display
% --------------------------------

if(size(info.Main.files,1) > 1)
  %Read in first file in list
  XPCS_maskOpenFile(info.Main.files{2})
end

switch info.Mask.theScale
  case 'Lin'
    %Set Scale to Linear
    set(hMenuLinear, 'checked', 'on');
  case 'Sqrt'
    %Set Scale to Square Root
    set(hMenuSqrt, 'checked', 'on');
  case 'Log'
    %Set Scale to Logarithmic
    set(hMenuLog, 'checked', 'on');
  case 'Tmap'
    %Set Scale to Tone Mapping
    set(hMenuTmap, 'checked', 'on');
end
switch info.Mask.theColor
  case 'Gray'
    %Set colormap to Gray
    set(hMenuGray, 'checked', 'on');
  case 'Jet'
    %Set colormap to Jet
    set(hMenuJet, 'checked', 'on');
  case 'HSV'
    %Set colormap to HSV
    set(hMenuHSV, 'checked', 'on');
  case 'Hot'
    %Set colormap to Hot
    set(hMenuHot, 'checked', 'on');
  case 'Cool'
    %Set colormap to Cool
    set(hMenuCool, 'checked', 'on');
end


%==========================================================================
% --- close request function of xpcsmask fig 
%==========================================================================
function mask_CloseRequestFcn(hObject,eventdata)
delete(findall(0,'Tag','mask_Fig'))

%----
% EOF
%----