function varargout = XPCS_MovieGUI(varargin)
% XPCS_MovieGUI: Open GUI to manipulate a movie of images
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/11/01

hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain,'Info');

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Opening movie control'; theString];
set(hMsgBox, 'String', theString);

%Check that there are enough frames to make a movie
frames = uint16(sum(cell2mat(info.Main.files(:,2))));
if(frames < 2)
  hMsgBox = findall(0,'Tag','main_MsgBox');
  theString = get(hMsgBox, 'String');
  theString = ['Not enough frames for a movie'; theString];
  set(hMsgBox, 'String', theString);
  return;
else
  hFigMovie = findall(0,'Tag','movie_Fig');
  if isempty(hFigMovie)
    initFigure;
  else
    figure(hFigMovie);
  end
end

%================================================================
% --- initialize movie figure layout
%================================================================
function initFigure
hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain,'Info');
% --------------------------------
% --- movie figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [500 150];
figurePos  = [150 520 figureSize];

hFigMovie = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Movie Control',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','movie_Fig',...
    'CloseRequestFcn',@movie_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigMovie,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','movie_Axes');
hGroupPatch = hggroup('Parent',hAxes);
hPatchMain = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --------------------------------
% --- file menu handles
% --------------------------------
hMenuFile = uimenu(hFigMovie,...
    'Label','&File',...
    'HandleVisibility','callback',...
    'Tag','movie_MenuFile');
hMenuExport = uimenu(hMenuFile,...
    'Label','&Export Movie ...',...
    'HandleVisibility','callback',...
    'Tag','movie_MenuExport',...
    'Accelerator','E',...
    'callback',@XPCS_movie);
hMenuClose = uimenu(hMenuFile,...
    'Label','&Close',...
    'HandleVisibility','callback',...
    'Tag','movie_MenuClose',...
    'Accelerator','Q',...
    'callback',@movie_CloseRequestFcn); %function within this m-file

% --------------------------------
% --- layout of controls
% --------------------------------
hTextFrames = uicontrol(hFigMovie,...
    'Style','text',...
    'Units','characters',...
    'String','Frame:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[10 8 10 1.6],...
    'Tag','movie_textFrames',...
    'Enable','on');
hEditFrame = uicontrol(hFigMovie,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[21 8 7 1.6],...
    'Tag','movie_editFrame',...
    'TooltipString','Enter the frame to view',...
    'Enable','on',...
    'String', '1',...
    'callback',@XPCS_frameSet);
hTextFrame = uicontrol(hFigMovie,...
    'Style','text',...
    'Units','characters',...
    'String','of 1',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[28 8 8 1.6],...
    'Tag','movie_textFrame',...
    'Enable','on');
hCBScale = uicontrol(hFigMovie,...
    'Style','checkbox',...
    'Units','characters',...
    'String','Autoscale',...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[40 8 20 1.6],...
    'Tag','movie_CBscale',...
    'TooltipString','Check to autoscale image. Otherwise, the given scale is used',...
    'Enable','on',...
    'BackgroundColor', backColor);
hTextDelay = uicontrol(hFigMovie,...
    'Style','text',...
    'Units','characters',...
    'String','Pause:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[65 8 9 1.6],...
    'Tag','movie_textDelay',...
    'Enable','on');
hEditDelay = uicontrol(hFigMovie,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'right',...
    'position',[75 8 7 1.6],...
    'Tag','movie_editDelay',...
    'TooltipString','Enter the wait time between frames',...
    'Enable','on',...
    'String', '0.1');
hTextTime = uicontrol(hFigMovie,...
    'Style','text',...
    'Units','characters',...
    'String','sec.',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[83 8 7 1.6],...
    'Tag','movie_textTime',...
    'Enable','on');
hSliderFrame = uicontrol(hFigMovie,...
    'Style','slider',...
    'Units','characters',...
    'position',[10 5 80 1.6],...
    'Tag','movie_sliderFrame',...
    'Enable','on',...
    'Max', 1,...
    'Min', 0,...
    'Value', 1,...
    'SliderStep',[.1 .1], ...
    'String' , ['.1' '.1'], ...
    'callback',@XPCS_frameSet);
hButtonLoadAll = uicontrol(hFigMovie,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Load All',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','on',...
    'position',[10 2 20 1.6],...
    'Tag','movie_buttonLoadAll',...
    'TooltipString','Reads in all of the files at ones for more fluid playback',...
    'callback',@XPCS_LoadAll);
hButtonPlay = uicontrol(hFigMovie,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Play',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','on',...
    'position',[40 2 20 1.6],...
    'Tag','movie_buttonPlay',...
    'TooltipString','Plays a movie of all the images',...
    'callback',@XPCS_movie);
hButtonStop = uicontrol(hFigMovie,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Stop',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','on',...
    'position',[70 2 20 1.6],...
    'Tag','movie_buttonStop',...
    'TooltipString','Interups the movie',...
    'callback',@XPCS_stop);

% --------------------------------
% Set Values
% --------------------------------
setappdata(hFigMovie, 'Interupt', 0)

frames = uint16(sum(cell2mat(info.Main.files(:,2))));
set(hTextFrame, 'String', sprintf('%s%u', 'of ', frames));
set(hSliderFrame, 'Max', frames);
set(hSliderFrame, 'Min', 1);
minStep = 1/(double(frames)-1);
majStep = 1/ceil(.1*(double(frames)-1));
set(hSliderFrame, 'SliderStep', [minStep majStep]);

if(info.Main.allFiles)
  set(hButtonLoadAll, 'Enable', 'off');
end

function movie_CloseRequestFcn(hObject,eventdata)
delete(findall(0,'Tag','movie_Fig'))

%----
% EOF
%----