function scaImg = XPCS_ScaleImg(origImg, factorX, varargin)
% XPCS_ScaleImg(origImg, factorX, factorY, newSize):
%  Scale the input image by the given factor via interpretation
% If only the scaling factor for X, factorX is given,
%  this is also used for the scaling factor for Y
% If the Y scaling factor is given, newSize, the [x y] pixels size array
%  of the new image can also be given to stretch the image
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/10/20

factorY = factorX;
newSize = size(origImg);
if(nargin >= 3)
  factorY = varargin{1};
end
if(nargin == 4)
  newSize = varargin{2};
end

data2 = double(origImg);
[xsize ysize] = size(data2);

[X Y] = meshgrid(-(xsize-1)/2:1:(xsize-1)/2,-(ysize-1)/2:1:(ysize-1)/2);
[XI YI] = meshgrid( ...
    -(newSize(1)-1)/2:1:(newSize(1)-1)/2, ...
    -(newSize(2)-1)/2:1:(newSize(2)-1)/2);
%stretch
XI = XI*(xsize/newSize(1));
YI = YI*(ysize/newSize(2));
%zoom
XI = XI/factorX;
YI = YI/factorY;

data3 = interp2(X,Y,double(data2),XI,YI,'spline');

if(factor < 1)
    %zoom out; fill in missing data with minimum values
    scaImg = min(min(data2))*ones(size(data2));
    xmin = ceil((xsize2+1-(xsize2-1)*factorX)/2);
    xmax = floor((xsize2+1+(xsize2-1)*factorX)/2);
    ymin = ceil((ysize2+1-(ysize2-1)*factorY)/2);
    ymax = floor((ysize2+1+(ysize2-1)*factorY)/2);
    scaImg(xmin: xmax, ymin: ymax) = ...
        data3(xmin: xmax, ymin: ymax);
else
    scaImg = data3;
end

%EOF%