function [varargout] = XPCS_convImgSize(oldImg, newSize, varargin)
% [newImg, updated] = XPCS_convImgSize(oldImg, newSize, scale):
%  Checks that the image is the same size as given and converts if not
%
% oldImg - the image to be checked
% newSize - the size the image should be
% scale - options to scale the image
%  cut - cut away excess or fill in missing with minimum value (default)
%  stretch - stretch the image via interpretation of pixels
% newImg - the returned image, changed to the new size
% updated - logical returned, which can be omitted
%  0 = the image is the same
%  1 = the image was updated
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/10/24

updated = 0;
if(nargout == 2)
  varargout = {oldImg, updated};
else
  varargout = {oldImg};
end
if(size(oldImg) ~= (newSize))
  updated = 1;
  
  scale = 'cut';
  if(nargin == 3)
    scale = varargin{1};
  end

  xdsize = newSize(1);
  ydsize = newSize(2);
  [xmsize ymsize] = size(oldImg);
  
  switch scale
    case 'cut'
      %adjust x-size
      if(xdsize < xmsize)
        %cut away
        offset=uint16((xmsize-xdsize)/2);
        tmp2 = oldImg(1+offset:xdsize+offset,1:ymsize);
      else
        %fill missing
        offset=uint16((xdsize-xmsize)/2);
        tmp2 = ones(xdsize,ymsize)*min(min(oldImg));
        tmp2(1+offset:xmsize+offset,1:ymsize) = oldImg;
      end
      
      %adjust y-size
      [xmsize ymsize] = size(tmp2);
      if(ydsize < ymsize)
        offset=uint16((ymsize-ydsize)/2);
        newImg = tmp2(1:xmsize,1+offset:ydsize+offset);
      else
        offset=uint16((ydsize-ymsize)/2);
        newImg = ones(xmsize,ydsize)*min(min(oldImg));
        newImg(1:xmsize,1+offset:ymsize+offset) = tmp2;
      end
    case 'stretch'
      newImg = XPCS_ScaleImg(oldImg, 1, 1, newSize);
  end
  if(nargout == 2)
    varargout = {newImg, updated};
  else
    varargout = {newImg};
  end
end

%-----
% EOF
%-----