function h = XPCS_fieSelGUI(num)
% XPCS_fieSelGUI: Opens a GUI to select the field for background adjustment
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/10/24

hFigFie = findall(0,'Tag','fie_Fig');

if isempty(hFigFie)
    initFigure(num);
else
    figure(hFigFie);
end

h = findall(0,'Tag','fie_Fig');
%================================================================
% --- initialize main Field Select layout
%================================================================
function initFigure(num)
hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain, 'Info');
% --------------------------------
% --- field select figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [500 350];
figurePos  = [350 330 figureSize];
hFigFie = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Background Field Select',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','fie_Fig',...
    'CloseRequestFcn',@fie_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigFie,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','fie_Axes');
hGroupPatch = hggroup('Parent',hAxes);
hPatchMain = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --- layout of controls
hGroupSel = uibuttongroup(hFigFie,...
    'Position',[0 0 1 1],...
    'BackgroundColor', backColor,...
    'SelectionChangeFcn',@fie_selection, ...
    'Tag','fie_groupSel');
hTextBGfunc = uicontrol(hFigFie,...
    'Style','text',...
    'Units','characters',...
    'String',['Background Function: ',info.Analysis.BGfunc],...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 24 75 1.6],...
    'Tag','fie_textBGfunc',...
    'Enable','on');
hTextBGcur = uicontrol(hFigFie,...
    'Style','text',...
    'Units','characters',...
    'String',['Choose option for Field: F',num2str(num)],...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 22 50 1.6],...
    'Tag','fie_textBGcur',...
    'Enable','on');
hRadioCur = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Current Field',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 19 45 1.6],...
    'Tag','fie_radioCur',...
    'Enable','on');
hRadioCon = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Constant Value',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 17 45 1.6],...
    'Tag','fie_radioCon',...
    'Enable','on');
hRadioMin = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Minimun of Selected Image(s)',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 15 45 1.6],...
    'Tag','fie_radioMin',...
    'Enable','on');
hRadioImg = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Select Image(s)',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 13 45 1.6],...
    'Tag','fie_radioImg',...
    'Enable','on');
hTextScale = uicontrol(hFigFie,...
    'Style','text',...
    'Units','characters',...
    'String','Scale Image:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 8 45 1.6],...
    'Tag','fie_textScale',...
    'Enable','on');
hTextEnergy = uicontrol(hFigFie,...
    'Style','text',...
    'Units','characters',...
    'String','Energy (KeV):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 6 25 1.6],...
    'Tag','fie_textEnergy',...
    'Enable','on');
hEditEnergy = uicontrol(hFigFie,...
    'Style','edit',...
    'Units','characters',...
    'String','',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[35 6 15 1.6],...
    'Tag','fie_editEnergy',...
    'TooltipString','Enter the used photon energy for this image',...
    'Enable','on',...
    'String', info.Setup.energy,...
    'callback',@XPCS_fieDisplay);
hTextWave = uicontrol(hFigFie,...
    'Style','text',...
    'Units','characters',...
    'String','Wavelength (A):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 4 25 1.6],...
    'Tag','fie_textWave',...
    'Enable','on');
hEditWave = uicontrol(hFigFie,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[35 4 15 1.6],...
    'Tag','fie_editWave',...
    'TooltipString','Enter the used photon wavelength for this image',...
    'Enable','on',...
    'String', info.Setup.wavelength,...
    'callback',@XPCS_fieDisplay);
hTextFactor = uicontrol(hFigFie,...
    'Style','text',...
    'Units','characters',...
    'String','Factor:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 2 25 1.6],...
    'Tag','fie_textFactor',...
    'Enable','on');
hEditFactor = uicontrol(hFigFie,...
    'Style','edit',...
    'Units','characters',...
    'String','',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[35 2 15 1.6],...
    'Tag','fie_editFactor',...
    'TooltipString','Enter the scaling factor for the image',...
    'Enable','on',...
    'String', '1',...
    'callback',@XPCS_fieDisplay);
hButtonClose = uicontrol(hFigFie,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Done',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','on',...
    'position',[70 3 20 1.6],...
    'Tag','fie_buttonClose',...
    'TooltipString','Saves selected value as current field and Closes GUI',...
    'callback',@fie_save);
hPlot = axes(...
    'Parent',hFigFie,...
    'Units','pixels',...
    'Position',[300 120 200 150],...
    'Tag','fie_Plot');

setappdata(hFigFie, 'Num', num);

theField = info.Analysis.BGfield{num, 1};
if(size(theField,1) == 1)
    theField = theField*ones(size(info.Mask.theData));
end
setappdata(hFigFie, 'Field', theField);
setappdata(hFigFie, 'finalField', theField);
imagesc('Parent', hPlot, 'CData', theField);
figure(hFigFie);
axis(hPlot, info.Mask.theAxis);
h = findobj('Tag','Colorbar');
if(isempty(h))
    colorbar('peer', hPlot,'location','EastOutside');
end

%==========================================================================
% --- change radio button
%==========================================================================
function fie_selection(hObject,eventdata)

hFigMain = findall(0,'Tag','main_Fig');
hFigFie = findall(0,'Tag','fie_Fig');
hPlot = findall(0,'Tag','fie_Plot');
hButtonClose = findall(0,'Tag','fie_buttonClose');
hFileList = findall(0,'Tag','main_fileList');

set(hButtonClose, 'enable', 'off');

info = getappdata(hFigMain, 'Info');
fields = info.Analysis.BGfield;

num = getappdata(hFigFie, 'Num');

switch get(eventdata.NewValue, 'Tag')
  case 'fie_radioCur'
    theField = fields{num,1};
  case 'fie_radioCon'
    theField = str2double(cellstr( ...
        inputdlg(['Enter the constant background field: F', ...
        num2str(num)], 'Input',1,{num2str(0)})));
    if(isempty(theField))
        hRadioCur = findall(0,'Tag','fie_radioCur');
        set(hObject, 'SelectedObject', hRadioCur)
        theField = fields{num,1};
    end
  case 'fie_radioMin'
    if(size(info.Main.files,1) == 1)
      pname = pwd;
    else
      %use last file as current directory
      aname = char(info.Main.files(size(info.Main.files,1)));
      fname = get(hFileList, 'String');
      if(isa(fname, 'char'))
        k = strfind(aname, fname);
      else
        k = strfind(aname, fname{size(fname,1),1});
      end
      pname = aname(1 : k(1)-2);
    end

    %Open Files
    [fname,pname,dataType] = uigetfile({'*.hdf','*.hdf';'*.FITS','*.FITS'}, ...
        'Select Data for Background Subtraction', pname, 'MultiSelect', 'on');
    if (pname ~= 0)
        theField = XPCS_fileReader(strcat(pname,fname), dataType, 'min');
    else
        hRadioCur = findall(0,'Tag','fie_radioCur');
        set(hObject, 'SelectedObject', hRadioCur)
        theField = fields{num,1};
    end
  case 'fie_radioImg'
    if(size(info.Main.files,1) == 1)
      pname = pwd;
    else
      %use last file as current directory
      aname = char(info.Main.files(size(info.Main.files,1)));
      fname = get(hFileList, 'String');
      if(isa(fname, 'char'))
        k = strfind(aname, fname); %this might be irrelavent, might always be cell now
      else
        k = strfind(aname, fname{size(fname,1),1});
      end
      pname = aname(1 : k(1)-2);
    end
    
    %Open Files
    [fname,pname,dataType] = uigetfile({'*.hdf','*.hdf';'*.FITS','*.FITS'}, ...
        'Select Data for Background Subtraction', pname, 'MultiSelect', 'on');
    if (pname ~= 0)
        theField = XPCS_fileReader(strcat(pname,fname), dataType, 'mean');
    else
        hRadioCur = findall(0,'Tag','fie_radioCur');
        set(hObject, 'SelectedObject', hRadioCur)
        theField = fields{num,1};
    end
end

setappdata(hFigFie, 'Field', theField);

if(size(theField,1) == 1)
    theField = theField*ones(size(info.Mask.theData));
end
imagesc('Parent', hPlot, 'CData', theField);
figure(hFigFie);
axis(hPlot, info.Mask.theAxis);
caxis([min(min(theField))-1, max(max(theField))+1]);
h = findobj('Tag','Colorbar');
if(isempty(h))
    colorbar('peer', hPlot,'location','EastOutside');
end

set(hButtonClose, 'enable', 'on');

%==========================================================================
% --- save field
%==========================================================================
function fie_save(hObject,eventdata)
hFigMain = findall(0,'Tag','main_Fig');
hFigFie = findall(0,'Tag','fie_Fig');

info = getappdata(hFigMain, 'Info');
theField = getappdata(hFigFie, 'Field');
num = getappdata(hFigFie, 'Num');

info.Analysis.BGfield(num,1) = {theField};
setappdata(hFigMain, 'Info', info);

fie_CloseRequestFcn

%==========================================================================
% --- close request function of field select fig 
%==========================================================================
function fie_CloseRequestFcn(hObject,eventdata)                             %#ok<INUSD>
delete(findall(0,'Tag','fie_Fig'))                                        ;

%----
% EOF
%----