function XPCS_mapImg(varargin)
% XPCS_mapImg: Creates a copy of an image on a particular scale and
% adjusts the viewing limits accordingly
% XPCS_mapImg(frame):
% frame - is an option to define which frame of the data should be displayed.
% Otherwise, first frame of data is displayed
% XPCS_mapImg(hObject, eventdata): arguments passed when an object calls
% this function. This is needed to know which object called the function
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.1  Date: 2010/11/04

hFigMain = findall(0,'Tag','main_Fig');
hEditLimit1 = findall(0,'Tag','mask_editLimit1');
hEditLimit2 = findall(0,'Tag','mask_editLimit2');
hMenuLinear = findall(0,'Tag','mask_MenuScaleLinear');
hMenuSqrt = findall(0,'Tag','mask_MenuScaleSqrt');
hMenuLog = findall(0,'Tag','mask_MenuScaleLog');
hMenuTmap = findall(0,'Tag','mask_MenuScaleTmap');

info = getappdata(hFigMain, 'Info');

hObject = -1;
frame = 1;
autoscale = 1;
if(nargin == 1)
  %frame is explicitly given
  frame = varargin{1};
  if(frame > size(info.Mask.theData,3))
    frame = size(info.Mask.theData,3);
  elseif(frame < 1)
    frame = 1;
  end
elseif(nargin == 2)
  hObject = varargin{1};
elseif(nargin == 3)
  hObject = varargin{1};
  %frame is explicitly given
  frame = varargin{3};
  if(frame > size(info.Mask.theData,3))
    frame = size(info.Mask.theData,3);
  elseif(frame < 1)
    frame = 1;
  end
elseif(nargin == 4)
  hObject = varargin{1};
  %frame is explicitly given
  frame = varargin{3};
  if(frame > size(info.Mask.theData,3))
    frame = size(info.Mask.theData,3);
  elseif(frame < 1)
    frame = 1;
  end
  autoscale = varargin{4};
end

newScale = 0;
%Set check marks in menu and theScale value
switch hObject
  case hMenuLinear
    %Set Scale to Linear
    if(~strcmp(info.Mask.theScale, 'Lin'))
      newScale = 1;
      info.Mask.theScale = 'Lin';
      set(hMenuLinear, 'checked', 'on');
      set(hMenuSqrt, 'checked', 'off');
      set(hMenuLog, 'checked', 'off');
      set(hMenuTmap, 'checked', 'off');
    end
  case hMenuSqrt
    %Set Scale to Square Root
    if(~strcmp(info.Mask.theScale, 'Sqrt'))
      newScale = 1;
      info.Mask.theScale = 'Sqrt';
      set(hMenuLinear, 'checked', 'off');
      set(hMenuSqrt, 'checked', 'on');
      set(hMenuLog, 'checked', 'off');
      set(hMenuTmap, 'checked', 'off');
    end
  case hMenuLog
    %Set Scale to Logarithmic
    if(~strcmp(info.Mask.theScale, 'Log'))
      newScale = 1;
      info.Mask.theScale = 'Log';
      set(hMenuLinear, 'checked', 'off');
      set(hMenuSqrt, 'checked', 'off');
      set(hMenuLog, 'checked', 'on');
      set(hMenuTmap, 'checked', 'off');
    end
  case hMenuTmap
    %Set Scale to Tone Mapping
    if(~strcmp(info.Mask.theScale, 'Tmap'))
      newScale = 1;
      info.Mask.theScale = 'Tmap';
      set(hMenuLinear, 'checked', 'off');
      set(hMenuSqrt, 'checked', 'off');
      set(hMenuLog, 'checked', 'off');
      set(hMenuTmap, 'checked', 'on');
    end
  case 0
    %new image should be displayed
    newScale = 1;
end

%map the image if it hasn't already been done
if(newScale)
  switch info.Mask.theScale
    case 'Lin'
      info.Mask.theImg = double(info.Mask.theData(:,:,frame));
    case 'Sqrt'
      info.Mask.theImg = sqrt(double(info.Mask.theData(:,:,frame)));
    case 'Log'
      info.Mask.theImg = log(double(info.Mask.theData(:,:,frame)));
    case 'Tmap'
      info.Mask.theImg = XPCS_toneMap(info.Mask.theData(:,:,frame));
  end
end

if(autoscale)
  %set the scale axis
  info.Mask.lowLmt = info.Mask.contrast*min(min(info.Mask.theImg));
  info.Mask.highLmt = max(max(info.Mask.theImg));
  if(info.Mask.highLmt == info.Mask.lowLmt)
    info.Mask.highLmt = info.Mask.highLmt + 1;
  end
end

setappdata(hFigMain, 'Info', info);

%set the edit limit boxes
set(hEditLimit1, 'String', info.Mask.lowLmt);
set(hEditLimit2, 'String', info.Mask.highLmt);

%Redisplay the image
XPCS_Redisplay(info.Mask.theImg, info.Mask.theMask);

%-----
%-EOF-
%-----