function XPCS_movie(varargin)
% XPCS_movie: Plays a movie of all the files in the Main file list
% with the current mask and zoom settings
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 2.1  Date: 2010/11/5

hFigMain = findall(0,'Tag','main_Fig');
hFigMask = findall(0,'Tag','mask_Fig');
info = getappdata(hFigMain, 'Info');
hFileList = findall(0,'Tag','main_fileList');
hMenuExport = findall(0,'Tag','movie_MenuExport');

hEditDelay = findall(0,'Tag','movie_editDelay');
hEditFrame = findall(0,'Tag','movie_editFrame');
hSliderFrame = findall(0,'Tag','movie_sliderFrame');
startF = get(hSliderFrame, 'Value'); 
endF = get(hSliderFrame, 'Max'); 

hCBScale = findall(0,'Tag','movie_CBscale');
autoscale = get(hCBScale, 'Value');

hFigMovie = findall(0,'Tag','movie_Fig');
setappdata(hFigMovie, 'Interupt', 0);

delay = str2double(get(hEditDelay, 'String'));

saveMovie = 0;
if(nargin == 2)
  hObject = varargin{1};
  if(hObject == hMenuExport)
    %movie should be saved
    saveMovie = 1;
  end
end

if(saveMovie)
  if(size(info.Main.files,1) == 1)
    pname = pwd;
  else
    %use last file as current directory
    aname = char(info.Main.files(size(info.Main.files,1)));
    fname = get(hFileList, 'String');
    k = strfind(aname, fname{size(fname,1),1});
    pname = aname(1 : k(1)-2);
  end

  [fname,pname] = uiputfile({'*.avi','Movie (*.avi)'},'Save Movie', ...
    pname);
  if (fname ~= 0)
  aviobj = avifile(sprintf('%s%s',pname,fname), ...
      'compression','None', 'fps', 1/delay);
  else
    return;
  end
end

if(~info.Main.allFiles)
  %Must load files
  for k=startF:endF
    if(getappdata(hFigMovie, 'Interupt'))
      if(saveMovie)
        aviobj = close(aviobj);
      end
      return;
    end
    %figure out which file it is
    frameSum = 0;
    row = 1;
    while(frameSum < k)
      row = row + 1;
      frameSum = frameSum + info.Main.files{row,2};
    end
    frame = k -(frameSum - info.Main.files{row,2});
    if(~strcmp(info.Main.files{row,1},info.Main.lastFile))
      info.Mask.theData = XPCS_fileReader(info.Main.files(row,1));
      info.Main.lastFile = info.Main.files{row,1};
      setappdata(hFigMain, 'Info', info);
    end
    XPCS_mapImg(0, {0}, frame, autoscale);
    pause(delay);
    set(hEditFrame, 'String', num2str(k));
    set(hSliderFrame, 'Value', k);
    if(saveMovie)
      aviobj = addframe(aviobj,getframe(hFigMask));
    end
  end
else
  %All files have been loaded, only need to recall them
  for k=startF:endF
    if(getappdata(hFigMovie, 'Interupt'))
      if(saveMovie)
        aviobj = close(aviobj);
      end
      return;
    end
    XPCS_mapImg(0, {0}, k, autoscale);
    pause(delay);
    set(hEditFrame, 'String', num2str(k));
    set(hSliderFrame, 'Value', k);
    if(saveMovie)
      aviobj = addframe(aviobj,getframe(hFigMask));
    end
  end
end

set(hEditFrame, 'String', num2str(1));
set(hSliderFrame, 'Value', 1);

if(saveMovie)
  aviobj = close(aviobj);
end

%-----
%-EOF-
%-----