function XPCS_openFiles(varargin)
% XPCS_openFiles: Allows user to select files to be read in for analysis
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 2.0  Date: 2010/10/27

hFigMain = findall(0,'Tag','main_Fig');
hFileList = findall(0,'Tag','main_fileList');
hButtonRun = findall(0,'Tag','main_buttonRun');
hButtonRemove = findall(0,'Tag','main_buttonRmv');
hButtonReset = findall(0,'Tag','main_buttonReset');
hButtonDown = findall(0,'Tag','main_buttonDown');
hButtonUp = findall(0,'Tag','main_buttonUp');
hTextCount = findall(0,'Tag','main_textCount');
hTextSize = findall(0,'Tag','main_textSize');
hTextLargestFile = findall(0,'Tag','main_textLargestFile');
hTextLargestSize = findall(0,'Tag','main_textLargestSize');
hTextFrame = findall(0,'Tag','movie_textFrame');
hSliderFrame = findall(0,'Tag','movie_sliderFrame');
hButtonLoadAll = findall(0,'Tag','movie_buttonLoadAll');

info = getappdata(hFigMain, 'Info');

%file list has changed, so
info.Main.allFiles = 0;
set(hButtonLoadAll, 'Enable', 'on');

if(size(info.Main.files,1) == 1)
    pname = pwd;
else
    %use last file as current directory
    aname = char(info.Main.files(size(info.Main.files,1)));
    fname = get(hFileList, 'String');
    k = strfind(aname, fname{size(fname,1),1});
    pname = aname(1 : k(1)-2);
end

%Open multiple Files
[fname,pname,dataType] = uigetfile({'*.hdf','*.hdf';'*.FITS','*.FITS'}, ...
    'Select Data for Correlation Analysis', ...
    pname, 'MultiSelect', 'on'); %sprintf('%s%s',pname,'\*.FITS') does not change dateType output

if(isa(fname, 'numeric'))
    %Open was canceled
    return;
elseif(isa(fname, 'char'))
    %convert to a single cell to keep format same
    fname = cellstr(fname);
end

temp1 = sort(fname)';
fileName = strcat(pname,temp1);
frames = cell(size(fileName,1),1);
for k = 1:size(fileName,1)
  if(dataType == 1)
    %.hdf
    frames{k,1} = 1;
  elseif(dataType == 2)
    %.fits
    infoFits = fitsinfo(fileName{k,1});
    if(isempty(infoFits.PrimaryData.Size))
      frames{k,1} = 1;
    else
      frames{k,1} = infoFits.PrimaryData.Size(3);
    end
  end
end
temp2 = [fileName, frames];

tmp = get(hFileList, 'String');
set(hFileList, 'String', [tmp; temp1]);
set(hFileList, 'Value', 1);
info.Main.files = [info.Main.files; temp2];

%go through files and find sum size, and largest
totalSize = 0;
largeSize = 0;
largeFile = '';
temp = get(hFileList, 'String');
for k = 2:size(info.Main.files, 1)
  tmp = dir(info.Main.files{k,1});
  totalSize = totalSize + tmp.bytes;
  if(tmp.bytes > largeSize)
    largeSize = tmp.bytes;
    largeFile = temp{k-1,1};
  end
end
largeSize = largeSize/1048576; %bytes -> MB
totalSize = totalSize/1048576; %bytes -> MB
set(hTextCount, 'String', sprintf('# Files: %u', ...
    uint16(size(info.Main.files, 1)-1)));
set(hTextSize, 'String', sprintf('Size: %6.2f MB', ...
    totalSize));
set(hTextLargestFile, 'String', sprintf('Largest: %s', ...
    largeFile));
set(hTextLargestSize, 'String', sprintf('Size: %6.2f MB', ...
    largeSize));

setappdata(hFigMain, 'Info', info);

%set movie control settings
frames = uint16(sum(cell2mat(info.Main.files(:,2))));
set(hTextFrame, 'String', sprintf('%s%s', 'of ', num2str(frames)));
set(hSliderFrame, 'Max', frames);
set(hSliderFrame, 'Min', 1);
minStep = 1/(double(frames)-1);
majStep = 1/ceil(.1*(double(frames)-1));
set(hSliderFrame, 'SliderStep', [minStep majStep]);

set(hButtonRun, 'Enable', 'on');
set(hButtonRemove, 'Enable', 'on');
set(hButtonReset, 'Enable', 'on');
set(hButtonDown, 'Enable', 'on');
set(hButtonUp, 'Enable', 'on');

%----
% EOF
%----