function XPCS_openFolder(varargin)
% XPCS_openFolder: Allows user to select all files in a folder to be read
% in for analysis
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 2.0  Date: 2010/11/02

hFigMain = findall(0,'Tag','main_Fig');
hFileList = findall(0,'Tag','main_fileList');
hButtonRun = findall(0,'Tag','main_buttonRun');
hButtonRemove = findall(0,'Tag','main_buttonRmv');
hButtonReset = findall(0,'Tag','main_buttonReset');
hButtonDown = findall(0,'Tag','main_buttonDown');
hButtonUp = findall(0,'Tag','main_buttonUp');
hTextCount = findall(0,'Tag','main_textCount');
hTextSize = findall(0,'Tag','main_textSize');
hTextLargestFile = findall(0,'Tag','main_textLargestFile');
hTextLargestSize = findall(0,'Tag','main_textLargestSize');
hTextFrame = findall(0,'Tag','movie_textFrame');
hSliderFrame = findall(0,'Tag','movie_sliderFrame');
hButtonLoadAll = findall(0,'Tag','movie_buttonLoadAll');

info = getappdata(hFigMain,'Info');

%file list has changed, so
info.Main.allFiles = 0;
set(hButtonLoadAll, 'Enable', 'on');

if(size(info.Main.files,1) == 1)
    pname = pwd;
else
    %use first file as current directory
    aname = char(info.Main.files(2));
    fname = get(hFileList, 'String');
    k = strfind(aname, fname{1,1});
    pname = aname(1 : k(1)-2);
end

%Select entire Folder
pname = uigetdir(pname, 'Select Folder for Correlation Analysis');
if(ischar(pname))
    flist = getFiles(pname);

    tmp = get(hFileList, 'String');
    set(hFileList, 'String', [tmp; flist(:,1)]);
    set(hFileList, 'Value', 1);
    
    %use full file name with path and add frame numbers
    fileName = strcat(sprintf('%s%s',pname,'\'),flist(:,1));
    frames = cell(size(fileName,1),1);
    for k = 1:size(fileName,1)
      %get extension
      switch flist{k,2}
        case '.hdf'
          %.hdf
          frames{k,1} = 1;
        case '.fits'
          %.fits
          infoFits = fitsinfo(fileName{k,1});
          if(isempty(infoFits.PrimaryData.Size))
            frames{k,1} = 1;
          else
            frames{k,1} = infoFits.PrimaryData.Size(3);
          end
      end
    end
    temp2 = [fileName, frames];

    info.Main.files = [info.Main.files; temp2];
    
    %go through files and find sum size, and largest
    temp = get(hFileList, 'String');
    totalSize = sum([flist{:,3}]);
    [largeSize, index] = max([flist{:,3}]);
    largeFile = flist{index,1};
    for k = 2:size(info.Main.files, 1)-size(flist,1)
      tmp = dir(info.Main.files{k,1});
      totalSize = totalSize + tmp.bytes;
      if(tmp.bytes > largeSize)
        largeSize = tmp.bytes;
        largeFile = temp{k-1,1};
      end
    end
    largeSize = largeSize/1048576; %bytes -> MB
    totalSize = totalSize/1048576; %bytes -> MB
    set(hTextCount, 'String', sprintf('# Files: %u', ...
      uint16(size(info.Main.files, 1)-1)));
    set(hTextSize, 'String', sprintf('Size: %6.2f MB', ...
      totalSize));
    set(hTextLargestFile, 'String', sprintf('Largest: %s', ...
      largeFile));
    set(hTextLargestSize, 'String', sprintf('Size: %6.2f MB', ...
      largeSize));
    
    setappdata(hFigMain, 'Info', info);
    
    %set movie control settings
    frames = uint16(sum(cell2mat(info.Main.files(:,2))));
    set(hTextFrame, 'String', sprintf('%s%s', 'of ', num2str(frames)));
    set(hSliderFrame, 'Max', frames);
    set(hSliderFrame, 'Min', 1);
    minStep = 1/(double(frames)-1);
    majStep = 1/ceil(.1*(double(frames)-1));
    set(hSliderFrame, 'SliderStep', [minStep majStep]);

    set(hButtonRun, 'Enable', 'on');
    set(hButtonRemove, 'Enable', 'on');
    set(hButtonReset, 'Enable', 'on');
    set(hButtonDown, 'Enable', 'on');
    set(hButtonUp, 'Enable', 'on');
end

%-------------------
% internal function
%-------------------
function list = getFiles(pname)
%returns all file names with extension of .hdf and .fits with their
%respective extension and file size

info=dir(pname);
entries = size(info,1);
list = cell(entries,3);
for j=3:1:entries
  [path, name, ext] = fileparts(info(j).name);
  if(strcmp(ext, '.hdf') || strcmp(ext, '.fits'))
    list(j,:) = {info(j).name, ext, info(j).bytes};
  end
end

%Erase empty cells
for j=entries:-1:1
  if(isempty(list{j,1}))
    list(j,:)=[];
  end
end

%----
% EOF
%----