function XPCS_remove(varargin)
% XPCS_remove: Removes files from the file list and adjust movie controls
% if necessary
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/11/01

hFigMain = findall(0,'Tag','main_Fig');
hFileList = findall(0,'Tag','main_fileList');
hButtonRun = findall(0,'Tag','main_buttonRun');
hButtonRemove = findall(0,'Tag','main_buttonRmv');
hButtonReset = findall(0,'Tag','main_buttonReset');
hButtonDown = findall(0,'Tag','main_buttonDown');
hButtonUp = findall(0,'Tag','main_buttonUp');
hTextCount = findall(0,'Tag','main_textCount');
hTextSize = findall(0,'Tag','main_textSize');
hTextLargestFile = findall(0,'Tag','main_textLargestFile');
hTextLargestSize = findall(0,'Tag','main_textLargestSize');
hTextFrame = findall(0,'Tag','movie_textFrame');
hSliderFrame = findall(0,'Tag','movie_sliderFrame');
hEditFrame = findall(0,'Tag','movie_editFrame');
hButtonLoadAll = findall(0,'Tag','movie_buttonLoadAll');

info = getappdata(hFigMain, 'Info');

%file list has changed, so
info.Main.allFiles = 0;
set(hButtonLoadAll, 'Enable', 'on');

tmp = get(hFileList, 'String');
index = get(hFileList, 'Value');
if(~isempty(tmp))
    if(iscellstr(tmp))
        tmp(index)=[];
    elseif(ischar(tmp))
        tmp=[];
    end
    info.Main.files(index+1,:)=[];
	set(hFileList, 'String', tmp);
    set(hFileList, 'Value', 1);
    setappdata(hFigMain, 'Info', info);
    
    %go through files and see find sum size, and largest
    totalSize = 0;
    largeSize = 0;
    largeFile = '';
    temp = get(hFileList, 'String');
    for k = 2:size(info.Main.files, 1)
      tmp = dir(info.Main.files{k,1});
      totalSize = totalSize + tmp.bytes;
      if(tmp.bytes > largeSize)
        largeSize = tmp.bytes;
        largeFile = temp{k-1,1};
      end
    end
    largeSize = largeSize/1048576; %bytes -> MB
    totalSize = totalSize/1048576; %bytes -> MB
    set(hTextCount, 'String', sprintf('# Files: %u', ...
        uint16(size(info.Main.files, 1)-1)));
    set(hTextSize, 'String', sprintf('Size: %6.2f MB', ...
        totalSize));
    set(hTextLargestFile, 'String', sprintf('Largest: %s', ...
        largeFile));
    set(hTextLargestSize, 'String', sprintf('Size: %6.2f MB', ...
        largeSize));
end

%Less than 2 frames in list (no movie)
frames = uint16(sum(cell2mat(info.Main.files(:,2))));
if(frames < 2)
    %close movie controlls
    delete(findall(0,'Tag','movie_Fig'))
else
    %set movie control settings
    if(str2double(get(hEditFrame, 'String')) > frames)
      set(hEditFrame, 'String', sprintf('%s', num2str(frames)));
    end
    set(hTextFrame, 'String', sprintf('%s%s', 'of ', num2str(frames)));
    set(hSliderFrame, 'Max', frames);
    set(hSliderFrame, 'Min', 1);
    minStep = 1/(double(frames)-1);
    majStep = 1/ceil(.1*(double(frames)-1));
    set(hSliderFrame, 'SliderStep', [minStep majStep]);
end

%No files in list
if(isempty(tmp))
    set(hButtonRun, 'Enable', 'off');
    set(hButtonRemove, 'Enable', 'off');
    set(hButtonReset, 'Enable', 'off');
    set(hButtonDown, 'Enable', 'off');
    set(hButtonUp, 'Enable', 'off');
end

%----
% EOF
%----