function h = XPCS_scaSelGUI(num)
% XPCS_scaSelGUI: Opens a GUI to select the scaling factor for 
% background adjustment
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

hFigSca = findall(0,'Tag','sca_Fig');

if isempty(hFigSca)
    initFigure(num);
else
    figure(hFigSca);
end

h = findall(0,'Tag','sca_Fig');

%================================================================
% --- initialize main Scaling Select layout
%================================================================
function initFigure(num)
hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain, 'Info');
% --------------------------------
% --- scaling select figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [500 375];
figurePos  = [350 330 figureSize];
hFigSca = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Background Scaling Select',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','sca_Fig',...
    'CloseRequestFcn',@sca_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigSca,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','sca_Axes');
hGroupPatch = hggroup('Parent',hAxes);
hPatchMain = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --- layout of controls
hGroupSel = uibuttongroup(hFigSca,...
    'Position',[0 0 1 1],...
    'BackgroundColor', backColor,...
    'SelectionChangeFcn',@sca_selection, ...
    'Tag','sca_groupSel');
hTextBGfunc = uicontrol(hFigSca,...
    'Style','text',...
    'Units','characters',...
    'String',['Background Function: ',info.Analysis.BGfunc],...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 26 75 1.6],...
    'Tag','sca_textBGfunc',...
    'Enable','on');
hTextBGcur = uicontrol(hFigSca,...
    'Style','text',...
    'Units','characters',...
    'String',['Choose option for Scale: S',num2str(num)],...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 24 75 1.6],...
    'Tag','sca_textBGcur',...
    'Enable','on');
hRadioCur = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Current Scale',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 20 50 1.6],...
    'Tag','sca_radioCur',...
    'Enable','on');
hRadioCon = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Constant Value',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[55 20 50 1.6],...
    'Tag','sca_radioCon',...
    'Enable','on');
hRadioMinM = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Min of minuend Field',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 18 50 1.6],...
    'Tag','sca_radioMinM',...
    'Enable','on');
hRadioMaxM = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Max of minuend  Field',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 16 50 1.6],...
    'Tag','sca_radioMaxM',...
    'Enable','on');
hRadioMinS = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Min of subtrahend Field',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[55 18 50 1.6],...
    'Tag','sca_radioMinS',...
    'Enable','on');
hRadioMaxS = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Max of subtrahend Field',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[55 16 50 1.6],...
    'Tag','sca_radioMaxS',...
    'Enable','on');
hRadioSum = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Minimize sum of difference field',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 14 100 1.6],...
    'Tag','sca_radioSum',...
    'Enable','on');
hRadioFlo = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Sets minimum of difference field to zero',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 12 100 1.6],...
    'Tag','sca_radioFlo',...
    'Enable','on');
hRadioBot = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Minimize sum of created field in region of low initial',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 8 100 1.6],...
    'Tag','sca_radioBot',...
    'Enable','on');
hRadioTop = uicontrol(hGroupSel,...
    'Style','radio',...
    'Units','characters',...
    'String','Minimize sum of created field in region of high initial',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'left',...
    'position',[5 6 100 1.6],...
    'Tag','sca_radioTop',...
    'Enable','on');
hButtonClose = uicontrol(hFigSca,...
    'Style','pushbutton',...
    'Units','characters',...
    'String','Done',...
    'FontSize', 10,...
    'Value', 0,...
    'Enable','on',...
    'Visible','on',...
    'position',[70 1 20 1.6],...
    'Tag','sca_buttonClose',...
    'TooltipString','Saves selected value as current scale and Closes GUI',...
    'callback',@sca_save);

setappdata(hFigSca, 'Num', num);
theScale = info.Analysis.BGscale{num, 1};
setappdata(hFigSca, 'Scale', theScale);

%==========================================================================
% --- change radio button
%==========================================================================
function sca_selection(hObject,eventdata)

hFigMain = findall(0,'Tag','main_Fig');
hFigSca = findall(0,'Tag','sca_Fig');
hButtonClose = findall(0,'Tag','sca_buttonClose');

set(hButtonClose, 'enable', 'off');

info = getappdata(hFigMain, 'Info');
scale = info.Analysis.BGscale;

num = getappdata(hFigSca, 'Num');

switch get(eventdata.NewValue, 'Tag')
  case 'sca_radioCur'
    theScale = scale{num,1};
  case 'sca_radioCon'
    theScale = str2double(cellstr( ...
        inputdlg(['Enter the constant scale: S', ...
        num2str(num)], 'Input',1,{num2str(0)})));
    if(isempty(theScale))
        hRadioCur = findall(0,'Tag','fie_radioCur');
        set(hObject, 'SelectedObject', hRadioCur)
        theScale = scale{num,1};
    end
  case 'sca_radioMinM'
    theScale = 'MinM';
  case 'sca_radioMaxM'
    theScale = 'MaxM';
  case 'sca_radioMinS'
    theScale = 'MinS';
  case 'sca_radioMaxS'
    theScale = 'MaxS';
  case 'sca_radioSum'
    theScale = 'Sum';
  case 'sca_radioFlo'
    theScale = 'Floor';
  case 'sca_radioBot'
    theScale = 'Bottom';
  case 'sca_radioTop'
    theScale = 'Top';

end

setappdata(hFigSca, 'Scale', theScale);



set(hButtonClose, 'enable', 'on');

%==========================================================================
% --- save field
%==========================================================================
function sca_save(hObject,eventdata)
hFigMain = findall(0,'Tag','main_Fig');
hFigSca = findall(0,'Tag','sca_Fig');

info = getappdata(hFigMain, 'Info');
theScale = getappdata(hFigSca, 'Scale');
num = getappdata(hFigSca, 'Num');

info.Analysis.BGscale(num,1) = {theScale};
setappdata(hFigMain, 'Info', info);

sca_CloseRequestFcn

%==========================================================================
% --- close request function of field select fig 
%==========================================================================
function sca_CloseRequestFcn(hObject,eventdata)                             %#ok<INUSD>
delete(findall(0,'Tag','sca_Fig'))                                        ;

%----
% EOF
%----