function XPCS_setupCCDscale(varargin)
% XPCS_setupCCDscale: Determines the scaling factor for the CCD
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

pi = 3.141529;

hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain,'Info');

L = info.Setup.dist;

w = info.Setup.width/2000;
h = info.Setup.height/2000;

th1 = info.Setup.theta1;
ph1 = info.Setup.phi1;
th2 = info.Setup.theta2;
ph2 = info.Setup.phi2;

lambda = info.Setup.wavelength;
data = info.Mask.theData;

p = [-w, -h, 0; w, -h, 0; -w, h, 0];

%rotate
Rx = [...
    1 0 0; ...
    0 cos(pi*(ph1+ph2)/180) sin(pi*(ph1+ph2)/180); ...
    0 -sin(pi*(ph1+ph2)/180) cos(pi*(ph1+ph2)/180)];
Ry = [...
    cos(-pi*(th1+th2)/180) 0 -sin(-pi*(th1+th2)/180); ...
    0 1 0; ...
    sin(-pi*(th1+th2)/180) 0 cos(-pi*(th1+th2)/180)];
%Rz = [ ...
%    cos(-pi*(th1+th2)/180) sin(-pi*(th1+th2)/180) 0; ...
%    -sin(-pi*(th1+th2)/180) cos(-pi*(th1+th2)/180) 0; ...
%    0 0 1];
for j = 1:size(p, 1)
    p(j,:) = Ry*Rx*p(j,:)';
end

%translate
p(:,1) = p(:,1)+L*cos(pi*ph1/180)*sin(pi*th1/180);                         %x component
p(:,2) = p(:,2)+L*sin(pi*ph1/180);                                         %y component
p(:,3) = p(:,3)+L*cos(pi*ph1/180)*cos(pi*th1/180);                         %z component

V = [p(2,:)-p(1,:);p(3,:)-p(1,:)];
[X, Y] = meshgrid(1:size(data,1), 1:size(data,2));

%get absolute location of each pixel: X*Vx +Y*Vy +x0
R(:,:,1) = X/size(data,1)*V(1,1) + Y/size(data,2)*V(2,1) + p(1,1);         %x component
R(:,:,2) = X/size(data,1)*V(1,2) + Y/size(data,2)*V(2,2) + p(1,2);         %y component
R(:,:,3) = X/size(data,1)*V(1,3) + Y/size(data,2)*V(2,3) + p(1,3);         %z component

%convert positions to angles
thePh = asin(R(:,:,2)...
    ./sqrt(R(:,:,1).*R(:,:,1) + R(:,:,2).*R(:,:,2) + R(:,:,3).*R(:,:,3)));
theTh = sign(R(:,:,1)).*acos(R(:,:,3) ...
    ./sqrt(R(:,:,1).*R(:,:,1) + R(:,:,3).*R(:,:,3)));

%make sure there are no Inf in theta
theTh(isinf(theTh)) = 0;

Qx = 2*pi*cos(thePh).*sin(theTh)/lambda;
Qy = 2*pi*sin(thePh)/lambda;
Qz = 2*pi*(cos(thePh).*cos(theTh)-1)/lambda;
Q = sqrt(Qx.*Qx + Qy.*Qy + Qz.*Qz);

info.Setup.CCDscale = [];
info.Setup.CCDscale(:,:,1) = Qx;
info.Setup.CCDscale(:,:,2) = Qy;
info.Setup.CCDscale(:,:,3) = Qz;

setappdata(hFigMain, 'Info', info);

%-----
% EOF
%-----