function XPCS_setupDisplay(hObject, eventdata, varargin)
% XPCS_setupDisplay: Display the setup
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Calculating the CCD Scaling...'; theString];                 %Has to be backwards because ListboxTop doesn't work on Uicontrol style edit
set(hMsgBox, 'String', theString);

hFigMain = findall(0,'Tag','main_Fig');
%hFigSetup = findall(0,'Tag','setup_Fig');
%figure(hFigSetup);
hPlotx = findall(0,'Tag','setup_Plotx');
hPloty = findall(0,'Tag','setup_Ploty');
hPlotz = findall(0,'Tag','setup_Plotz');
hPlotqx = findall(0,'Tag','setup_Plotqx');
hPlotqy = findall(0,'Tag','setup_Plotqy');
hPlotqz = findall(0,'Tag','setup_Plotqz');
hPlotq = findall(0,'Tag','setup_Plotq');
info = getappdata(hFigMain,'Info');

if(exist('hObject', 'var'))
    theNum = str2double(get(hObject, 'String'));
    if isnan(theNum)
        errordlg('You must enter a numeric value','Bad Input','modal')
        uicontrol(hObject)
        return
    end
    switch get(hObject, 'Tag')
        case 'setup_editEnergy'
            info.Setup.energy = theNum;
            info.Setup.wavelength = 12.3985237/theNum;
            set(findall(0,'Tag','setup_editWave'), 'String', 12.3985237/theNum);
        case 'setup_editWave'
            info.Setup.wavelength = theNum;
            info.Setup.energy = 12.3985237/theNum;
            set(findall(0,'Tag','setup_editEnergy'), 'String', 12.3985237/theNum);
        case 'setup_editDist'
            info.Setup.dist = theNum;
        case 'setup_editWidth'
            info.Setup.width = theNum;
        case 'setup_editHeight'
            info.Setup.height = theNum;
        case 'setup_editPh1'
            info.Setup.phi1 = theNum;
        case 'setup_editTh1'
            info.Setup.theta1 = theNum;
        case 'setup_editPh2'
            info.Setup.phi2 = theNum;
        case 'setup_editTh2'
            info.Setup.theta2 = theNum;
        case 'setup_editScale'
            info.Setup.scale = theNum;
    end
end

cla(hPlotx);
cla(hPloty);
cla(hPlotz);
cla(hPlotqx);
cla(hPlotqy);
cla(hPlotqz);
cla(hPlotq);

x = info.Setup.scale;

L = info.Setup.dist;

w = x*info.Setup.width/2000;
h = x*info.Setup.height/2000;
d = x*(info.Setup.width+info.Setup.height)/10000;

th1 = info.Setup.theta1;
ph1 = info.Setup.phi1;
th2 = info.Setup.theta2;
ph2 = info.Setup.phi2;

%detector
vert1 = [ ...
    w h 0; ...
    w -h 0; ...
    -w -h 0; ...
    -w h 0; ...
    w h d; ...
    w -h d; ...
    -w -h d; ...
    -w h d];
face1 = [ ...
    1 2 3 4; ...
    1 2 6 5; ...
    2 3 7 6; ...
    3 4 8 7; ...
    4 1 5 8; ...
    5 6 7 8];

%rotate
Rx = [...
    1 0 0; ...
    0 cos(pi*(ph1+ph2)/180) sin(pi*(ph1+ph2)/180); ...
    0 -sin(pi*(ph1+ph2)/180) cos(pi*(ph1+ph2)/180)];
Ry = [...
    cos(-pi*(th1+th2)/180) 0 -sin(-pi*(th1+th2)/180); ...
    0 1 0; ...
    sin(-pi*(th1+th2)/180) 0 cos(-pi*(th1+th2)/180)];
%Rz = [ ...
%    cos(-pi*(th1+th2)/180) sin(-pi*(th1+th2)/180) 0; ...
%    -sin(-pi*(th1+th2)/180) cos(-pi*(th1+th2)/180) 0; ...
%    0 0 1];
for j = 1:size(vert1, 1)
    vert1(j,:) = Ry*Rx*vert1(j,:)';
end

%translate
vert1(:,1) = vert1(:,1)+L*cos(pi*ph1/180)*sin(pi*th1/180);
vert1(:,2) = vert1(:,2)+L*sin(pi*ph1/180);
vert1(:,3) = vert1(:,3)+L*cos(pi*ph1/180)*cos(pi*th1/180);

%set color
cdata(:,:,1) = [1 0 0 0 0 0];
cdata(:,:,2) = [0 0 0 0 0 0];
cdata(:,:,3) = [1 0 0 0 0 0];

%draw sample
l = x/1000;
vert2 = [ ...
    l l -l; ...
    l -l -l; ...
    -l -l -l; ...
    -l l -l; ...
    l l l; ...
    l -l l; ...
    -l -l l; ...
    -l l l];
face2 = [ ...
    1 2 3 4; ...
    1 2 6 5; ...
    2 3 7 6; ...
    3 4 8 7; ...
    4 1 5 8; ...
    5 6 7 8];

%draw lines
line1 = [0 0 -L; 0 0 L/2];
line2 = [0 0 0; ...
    L*cos(pi*ph1/180)*sin(pi*th1/180) ...
    L*sin(pi*ph1/180) ...
    L*cos(pi*ph1/180)*cos(pi*th1/180)];

%xplot
p = patch('Parent', hPlotx, 'vertices', vert1, 'faces', face1);
set(p,'FaceColor','flat','CData',cdata)
patch('Parent', hPlotx, 'vertices', vert2, 'faces', face2, 'facecolor', 'g');
patch('Parent', hPlotx, 'vertices', line1, 'faces', [1 2], 'edgecolor', 'b');
patch('Parent', hPlotx, 'vertices', line2, 'faces', [1 2], 'edgecolor', 'r');
axis(hPlotx,[-(L+d) L+d -(L+d) L+d -(L+d) L+d]);
view(hPlotx,[-90 0]);

%yplot
p = patch('Parent', hPloty, 'vertices', vert1, 'faces', face1);
set(p,'FaceColor','flat','CData',cdata)
patch('Parent', hPloty, 'vertices', vert2, 'faces', face2, 'facecolor', 'g');
patch('Parent', hPloty, 'vertices', line1, 'faces', [1 2], 'edgecolor', 'b');
patch('Parent', hPloty, 'vertices', line2, 'faces', [1 2], 'edgecolor', 'r');
axis(hPloty,[-(L+d) L+d -(L+d) L+d -(L+d) L+d]);
view(hPloty,[180 0]);

%zplot
p = patch('Parent', hPlotz, 'vertices', vert1, 'faces', face1);
set(p,'FaceColor','flat','CData',cdata)
patch('Parent', hPlotz, 'vertices', vert2, 'faces', face2, 'facecolor', 'g');
patch('Parent', hPlotz, 'vertices', line1, 'faces', [1 2], 'edgecolor', 'b');
patch('Parent', hPlotz, 'vertices', line2, 'faces', [1 2], 'edgecolor', 'r');
axis(hPlotz,[-(L+d) L+d -(L+d) L+d -(L+d) L+d]);
view(hPlotz,[180 -90]);

setappdata(hFigMain, 'Info', info);

%plot CCD scaling
XPCS_setupCCDscale
info = getappdata(hFigMain, 'Info');
Q = info.Setup.CCDscale;
imagesc('Parent', hPlotq, 'CData', ...
    sqrt(Q(:,:,1).*Q(:,:,1) + Q(:,:,2).*Q(:,:,2) + Q(:,:,2).*Q(:,:,2)));
imagesc('Parent', hPlotqx, 'CData',Q(:,:,1));
imagesc('Parent', hPlotqy, 'CData',Q(:,:,2));
imagesc('Parent', hPlotqz, 'CData',Q(:,:,3));
set(hPlotq, 'XLim', [0 size(Q,1)]);
set(hPlotq, 'YLim', [0 size(Q,2)]);
set(hPlotqx, 'XLim', [0 size(Q,1)]);
set(hPlotqx, 'YLim', [0 size(Q,2)]);
set(hPlotqy, 'XLim', [0 size(Q,1)]);
set(hPlotqy, 'YLim', [0 size(Q,2)]);
set(hPlotqz, 'XLim', [0 size(Q,1)]);
set(hPlotqz, 'YLim', [0 size(Q,2)]);

theString = ['done'; theString];
set(hMsgBox, 'String', theString);

%-----
% EOF
%-----