function varargout = XPCS_setupGUI(varargin)
% XPCS_setupGUI: Open GUI to define the physical setup
%
% Copyright 2010
% Sebastian Dietze
% University of California, San Diego

% Revision: 1.0  Date: 2010/08/27

hMsgBox = findall(0,'Tag','main_MsgBox');
theString = get(hMsgBox, 'String');
theString = ['Opening experimental setup interface'; theString];
set(hMsgBox, 'String', theString);
  
hFigSetup = findall(0,'Tag','setup_Fig');
if isempty(hFigSetup)
    initFigure;
else
    figure(hFigSetup);
end

%================================================================
% --- initialize main figure layout
%================================================================
function initFigure
hFigMain = findall(0,'Tag','main_Fig');
info = getappdata(hFigMain,'Info');
% --------------------------------
% --- main figure handle
% --------------------------------
backColor = [0 .7 1];
figureSize = [750 540];
figurePos  = [150 130 figureSize];
hFigSetup = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','off',...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','XPCS Setup Definition',...
    'Position',figurePos,...
    'HandleVisibility','callback',...
    'Tag','setup_Fig',...
    'CloseRequestFcn',@setup_CloseRequestFcn,...
    'UserData',[]);
hAxes = axes(...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[0 0 figureSize],...
    'Tag','setup_Axes');
hGroupPatch = hggroup('Parent',hAxes);
hPatchMain = patch(...
    'Parent',hGroupPatch,...
    'XData',[0 1 1 0],...
    'YData',[0 0 1 1],...
    'FaceColor',[.7 .7 0.7],...
    'EdgeColor',[0.7 .7 0.7]);
set(get(hGroupPatch,'Children'),...
    'FaceColor', backColor,...
    'EdgeColor',[0.7 0.7 0.7]);

% --- layout of plot
text('Parent',hAxes,...
    'Position',[0.07 .96],...
    'FontSize', 12,...
    'FontWeight', 'Bold',...
    'String','Enter the setup parameters for q scaling.',...
    'Units','normalized',...
    'HorizontalAlignment','Left',...
    'Color',[0.0 0.0 0]);
hPlotx = subplot(4,5,[1:2;6,7],...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[50 300 200 200],...
    'Tag','setup_Plotx');
hPloty = subplot(4,5,[3:4;8,9],...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[275 300 200 200],...
    'Tag','setup_Ploty');
hPlotz = subplot(4,5,[11:12;16,17],...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[50 75 200 200],...
    'Tag','setup_Plotz');
hPlotqx = subplot(4,5,13, ...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[305 192.5 70 70],...
    'Tag','setup_Plotqx');
hPlotqy = subplot(4,5,14, ...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[417.5 192.5 70 70],...
    'Tag','setup_Plotqy');
hPlotqz = subplot(4,5,18, ...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[305 80 70 70],...
    'Tag','setup_Plotqz');
hPlotq = subplot(4,5,19, ...
    'Parent',hFigSetup,...
    'Units','pixels',...
    'Position',[417.5 80 70 70],...
    'Tag','setup_Plotq');

% --------------------------------
% --- file menu handles
% --------------------------------
hMenuFile = uimenu(hFigSetup,...
    'Label','&File',...
    'HandleVisibility','callback',...
    'Tag','setup_MenuFile');
hMenuImport = uimenu(hMenuFile,...
    'Label','&Import ...',...
    'HandleVisibility','callback',...
    'Tag','setup_MenuImport',...
    'Accelerator','I',...
    'callback',@XPCS_setupImport); % additional m-file
hMenuExport = uimenu(hMenuFile,...
    'Label','&Export ...',...
    'HandleVisibility','callback',...
    'Tag','setup_MenuExport',...
    'Accelerator','E',...
    'callback',@XPCS_setupImport); % additional m-file
hMenuClose = uimenu(hMenuFile,...
    'Label','&Close',...
    'HandleVisibility','callback',...
    'Tag','setup_MenuClose',...
    'Accelerator','Q',...
    'callback',@setup_CloseRequestFcn); %function within this m-file

% --- layout of controls
hTextEnergy = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Energy (KeV):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 34 22 1.6],...
    'Tag','setup_textEnergy',...
    'Enable','on');
hEditEnergy = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 34 10 1.6],...
    'Tag','setup_editEnergy',...
    'TooltipString','Enter energy of photons',...
    'Enable','on',...
    'String', info.Setup.energy,...
    'callback',@XPCS_setupDisplay);
hTextWave = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Wavelength (A):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 32 22 1.6],...
    'Tag','setup_textWave',...
    'Enable','on');
hEditWave = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 32 10 1.6],...
    'Tag','setup_editWave',...
    'TooltipString','Enter wavelength of photons',...
    'Enable','on',...
    'String', info.Setup.wavelength,...
    'callback',@XPCS_setupDisplay);
hTextDetect = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Detector:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'center',...
    'position',[110 28 22 1.6],...
    'Tag','setup_textDetect',...
    'Enable','on');
hTextDist = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Distance (m):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 26 22 1.6],...
    'Tag','setup_textDist',...
    'Enable','on');
hEditDist = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 26 10 1.6],...
    'Tag','setup_editDist',...
    'TooltipString','Enter the distance from the sample to the center of the detector plate',...
    'Enable','on',...
    'String', info.Setup.dist,...
    'callback',@XPCS_setupDisplay);
hTextWidth = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Width (mm):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 24 22 1.6],...
    'Tag','setup_textWidth',...
    'Enable','on');
hEditWidth = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 24 10 1.6],...
    'Tag','setup_editWidth',...
    'TooltipString','Enter the width of the detector plate',...
    'Enable','on',...
    'String', info.Setup.width,...
    'callback',@XPCS_setupDisplay);
hTextHeight = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Height (mm):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 22 22 1.6],...
    'Tag','setup_textHeight',...
    'Enable','on');
hEditHeight = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 22 10 1.6],...
    'Tag','setup_editHeight',...
    'TooltipString','Enter the height of the detector plate',...
    'Enable','on',...
    'String', info.Setup.height,...
    'callback',@XPCS_setupDisplay);
hTextPh1 = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Phi1 (deg.):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 20 22 1.6],...
    'Tag','setup_textPh1',...
    'Enable','on');
hEditPh1 = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 20 10 1.6],...
    'Tag','setup_editPh1',...
    'TooltipString','Enter the angle between the direct beam and detector',...
    'Enable','on',...
    'String', info.Setup.phi1,...
    'callback',@XPCS_setupDisplay);
hTextTh1 = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Theta1 (deg.):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 18 22 1.6],...
    'Tag','setup_textTh1',...
    'Enable','on');
hEditTh1 = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 18 10 1.6],...
    'Tag','setup_editTh1',...
    'TooltipString','Enter the in plane angle between the direct beam and detector',...
    'Enable','on',...
    'String', info.Setup.theta1,...
    'callback',@XPCS_setupDisplay);
hTextPh2 = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Phi2 (deg.):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 16 22 1.6],...
    'Tag','setup_textPh2',...
    'Enable','on');
hEditPh2 = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 16 10 1.6],...
    'Tag','setup_editPh2',...
    'TooltipString','Enter the angle between the direct beam and detector',...
    'Enable','on',...
    'String', info.Setup.phi2,...
    'callback',@XPCS_setupDisplay);
hTextTh2 = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Theta2 (deg.):',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 14 22 1.6],...
    'Tag','setup_textTh2',...
    'Enable','on');
hEditTh2 = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 14 10 1.6],...
    'Tag','setup_editTh2',...
    'TooltipString','Enter the in plane angle between the direct beam and detector',...
    'Enable','on',...
    'String', info.Setup.theta2,...
    'callback',@XPCS_setupDisplay);
hTextScale = uicontrol(hFigSetup,...
    'Style','text',...
    'Units','characters',...
    'String','Object Scale:',...
    'FontSize', 12,...
    'BackgroundColor', backColor,...
    'HorizontalAlignment', 'right',...
    'position',[110 8 22 1.6],...
    'Tag','setup_textScale',...
    'Enable','on');
hEditScale = uicontrol(hFigSetup,...
    'Style','edit',...
    'Units','characters',...
    'FontSize', 12,...
    'HorizontalAlignment', 'left',...
    'position',[133 8 10 1.6],...
    'Tag','setup_editScale',...
    'TooltipString','Enter the scale of the objects for better viewing',...
    'Enable','on',...
    'String', info.Setup.scale,...
    'callback',@XPCS_setupDisplay);

%-----
% Default display
%-----
XPCS_setupDisplay;

%==========================================================================
% --- close request function of xpcsmask fig 
%==========================================================================
function setup_CloseRequestFcn(hObject,eventdata)                             %#ok<INUSD>
delete(findall(0,'Tag','setup_Fig'))                                        ;

% ---
%EOF%